@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -56,7 +56,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: alert.c,v 1.36 2004/08/15 19:55:40 martinp Exp $
+ *  @version \$Id: alert.c,v 1.41 2005/02/13 00:00:13 martinp Exp $
  *  @file
  */
 
@@ -97,7 +97,7 @@ void handle_alert(Event_T E) {
       
       if(IS_EVENT_SET(m->events, Event_get_id(E))) {
 
-	Mail_T tmp;
+	Mail_T tmp= NULL;
 
 	NEW(tmp);
 
@@ -108,7 +108,7 @@ void handle_alert(Event_T E) {
 	}
 
 	substitute(&tmp, s->name, EVENT_DESCRIPTION(E),
-          EVENTACTION_DESCRIPTION(E));
+          Event_get_action_description(E));
 
 	replace_bare_linefeed(&tmp);
 
@@ -139,7 +139,7 @@ void handle_alert(Event_T E) {
 
       if(!skip && IS_EVENT_SET(m->events, Event_get_id(E))) {
 
-	Mail_T tmp;
+	Mail_T tmp= NULL;
 
 	NEW(tmp);
 
@@ -149,7 +149,7 @@ void handle_alert(Event_T E) {
 	  tmp->opt_message= xstrdup(Event_get_message(E));
 
 	substitute(&tmp, s->name, EVENT_DESCRIPTION(E),
-          EVENTACTION_DESCRIPTION(E));
+          Event_get_action_description(E));
 
 	replace_bare_linefeed(&tmp);
 
@@ -177,33 +177,30 @@ void handle_alert(Event_T E) {
 
 
 static void substitute(Mail_T *m, char *name, const char *event,
-  const char *action) {
+		       const char *action) {
 
   char host[STRLEN];
-  char *now= get_RFC822date(NULL);
+  char now[STRLEN];
 
   ASSERT(m && name && event && action);
 
+  Util_getRFC822Date(NULL, now, STRLEN);
   if(gethostname(host, sizeof(host)) < 0) {
     snprintf(host, STRLEN, "%s", LOCALHOST);
   }
-
-  replace_string(&(*m)->from, "$HOST", host);
-  replace_string(&(*m)->subject, "$DATE", now);
-  replace_string(&(*m)->message, "$DATE", now);
-  replace_string(&(*m)->subject, "$HOST", host);
-  replace_string(&(*m)->message, "$HOST", host);
-  replace_string(&(*m)->subject, "$PROGRAM", name);
-  replace_string(&(*m)->message, "$PROGRAM", name);
-  replace_string(&(*m)->subject, "$SERVICE", name);
-  replace_string(&(*m)->message, "$SERVICE", name);
-  replace_string(&(*m)->subject, "$EVENT", event);
-  replace_string(&(*m)->message, "$EVENT", event);
-  replace_string(&(*m)->subject, "$ACTION", action);
-  replace_string(&(*m)->message, "$ACTION", action);
- 
-  FREE(now);
-
+  Util_replaceString(&(*m)->from, "$HOST", host);
+  Util_replaceString(&(*m)->subject, "$DATE", now);
+  Util_replaceString(&(*m)->message, "$DATE", now);
+  Util_replaceString(&(*m)->subject, "$HOST", host);
+  Util_replaceString(&(*m)->message, "$HOST", host);
+  Util_replaceString(&(*m)->subject, "$PROGRAM", name);
+  Util_replaceString(&(*m)->message, "$PROGRAM", name);
+  Util_replaceString(&(*m)->subject, "$SERVICE", name);
+  Util_replaceString(&(*m)->message, "$SERVICE", name);
+  Util_replaceString(&(*m)->subject, "$EVENT", event);
+  Util_replaceString(&(*m)->message, "$EVENT", event);
+  Util_replaceString(&(*m)->subject, "$ACTION", action);
+  Util_replaceString(&(*m)->message, "$ACTION", action);
 }
 
 
@@ -236,12 +233,12 @@ static void copy_mail(Mail_T n, Mail_T o) {
 
 
 static void replace_bare_linefeed(Mail_T *m) {
-
-  replace_string(&(*m)->message, "\r\n", "\n");
-  replace_string(&(*m)->message, "\n", "\r\n");
+  
+  Util_replaceString(&(*m)->message, "\r\n", "\n");
+  Util_replaceString(&(*m)->message, "\n", "\r\n");
   if((*m)->opt_message) {
-    replace_string(&(*m)->opt_message, "\r\n", "\n");
-    replace_string(&(*m)->opt_message, "\n", "\r\n");
+    Util_replaceString(&(*m)->opt_message, "\r\n", "\n");
+    Util_replaceString(&(*m)->opt_message, "\n", "\r\n");
   }
-
+  
 }
