@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -60,7 +60,7 @@
  *  @author Rory Toma, <rory@digeo.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: control.c,v 1.83 2004/08/28 08:31:07 martinp Exp $
+ *  @version \$Id: control.c,v 1.89 2005/03/14 23:11:46 martinp Exp $
  *
  *  @file
  */
@@ -74,7 +74,6 @@ static int   do_stop(Service_T);
 static void  do_monitor(Service_T);
 static void  do_unmonitor(Service_T);
 static void  monitor_set(Service_T);
-static void  monitor_unset(Service_T);
 static void *wait_start(void *);
 static int   wait_stop(Service_T);
 static void  do_depend(Service_T, const char *);
@@ -91,14 +90,14 @@ static void  do_depend(Service_T, const char *);
 void control_service_daemon(const char *S, const char *action) {
 
   Socket_T s;
-  char *auth= get_basic_authentication_header();
+  char *auth= Util_getBasicAuthHeader();
 
   ASSERT(S);
   ASSERT(action);
 
 
   s= socket_new(Run.bind_addr?Run.bind_addr:"localhost",
-		Run.httpdport, SOCKET_TCP, Run.httpdssl);
+		Run.httpdport, SOCKET_TCP, Run.httpdssl, NET_TIMEOUT);
   
   if(!s) {
     
@@ -108,7 +107,8 @@ void control_service_daemon(const char *S, const char *action) {
     
   } else {
 
-    socket_print(s, "GET /%s?action=%s HTTP/1.0\r\n%s\r\n", S, action, auth);
+    socket_print(s,
+      "GET /%s?action=%s HTTP/1.0\r\n%s\r\n", S, action, auth?auth:"");
     socket_free(&s);
       
   }
@@ -132,7 +132,7 @@ void control_service(const char *S, const char *action) {
   ASSERT(S);
   ASSERT(action);
 
-  if(!(s= get_service(S))) {
+  if(!(s= Util_getService(S))) {
     log("%s: Cannot %s service '%s' -- not found in %s\n",
           prog, action, S, Run.controlfile);
     return;
@@ -140,7 +140,7 @@ void control_service(const char *S, const char *action) {
 
   if(IS(action, "start")) {
     
-    if(s->type==TYPE_PROCESS && is_process_running(s)) {
+    if(s->type==TYPE_PROCESS && Util_isProcessRunning(s)) {
       DEBUG("%s: Process already running -- process %s\n", prog, S);
       monitor_set(s);
       return;
@@ -160,7 +160,7 @@ void control_service(const char *S, const char *action) {
     
     if(s->type==TYPE_PROCESS && !s->stop) {
       DEBUG("%s: Stop method not defined -- process %s\n", prog, S);
-      monitor_unset(s);
+      Util_monitorUnset(s);
       return;
     }
     
@@ -241,7 +241,7 @@ static void do_start(Service_T s) {
     
     for(d= s->dependantlist; d; d= d->next ) {
       
-      Service_T parent= get_service(d->dependant);
+      Service_T parent= Util_getService(d->dependant);
       ASSERT(parent);
       do_start(parent);
       
@@ -249,7 +249,7 @@ static void do_start(Service_T s) {
 
   }
   
-  if(s->start && (s->type!=TYPE_PROCESS || !is_process_running(s))) {
+  if(s->start && (s->type!=TYPE_PROCESS || !Util_isProcessRunning(s))) {
     int status;
     pthread_t thread;
 
@@ -291,14 +291,9 @@ static int do_stop(Service_T s) {
  
   s->depend_visited= TRUE;
  
-  monitor_unset(s);
+  Util_monitorUnset(s);
 
-  if(s->type==TYPE_PROCESS) {
-    /* Reset the proc info object in case of a later restart */
-    reset_procinfo(s);
-  }
-
-  if(s->stop && (s->type!=TYPE_PROCESS || is_process_running(s))) {
+  if(s->stop && (s->type!=TYPE_PROCESS || Util_isProcessRunning(s))) {
     log("'%s' stop: %s\n", s->name, s->stop->arg[0]);
     spawn(s, s->stop, "Stopped");
 
@@ -334,7 +329,7 @@ static void do_monitor(Service_T s) {
     
     for(d= s->dependantlist; d; d= d->next ) {
       
-      Service_T parent= get_service(d->dependant);
+      Service_T parent= Util_getService(d->dependant);
       ASSERT(parent);
       do_monitor(parent);
       
@@ -359,13 +354,8 @@ static void do_unmonitor(Service_T s) {
  
   s->depend_visited= TRUE;
   
-  monitor_unset(s);
+  Util_monitorUnset(s);
    
-  if(s->type==TYPE_PROCESS) {
-    /* Reset the proc info object in case of a later restart */
-    reset_procinfo(s);
-  }
-  
 }
 
 
@@ -385,22 +375,6 @@ static void monitor_set(Service_T s) {
 }
 
 
-/*
- * This will disable service monitoring in the case that it is enabled
- * @param s A Service_T object
- */
-static void monitor_unset(Service_T s) {
-
-  ASSERT(s);
-
-  if(s->monitor) {
-    s->monitor= MONITOR_NOT;
-    DEBUG("Monitoring disabled -- service %s\n", s->name);
-  }
-
-}
-
-
 /*
  * This is an in-fix recursive function called before s is started to
  * stop every service that depends on s, in reverse order *or* after s
@@ -463,12 +437,12 @@ static void *wait_start(void *service) {
   pthread_detach(pthread_self());
 
   while(max_tries-- && !Run.stopped) {
-    if(is_process_running(s))
+    if(Util_isProcessRunning(s))
       break;
     sleep(1);
   }
   
-  if(!is_process_running(s)) {
+  if(!Util_isProcessRunning(s)) {
     Event_post(s, EVENT_EXEC, TRUE, s->action_EXEC,
       "'%s' failed to start", s->name);
   } else {
@@ -501,12 +475,12 @@ static int wait_stop(Service_T s) {
   ASSERT(s);
 
   while(max_tries-- && !Run.stopped) {
-    if(!is_process_running(s))
+    if(!Util_isProcessRunning(s))
       break;
     sleep(1);
   }
 
-  if(is_process_running(s)) {
+  if(Util_isProcessRunning(s)) {
     Event_post(s, EVENT_EXEC, TRUE, s->action_EXEC,
       "'%s' failed to stop", s->name);
     return FALSE;
