@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@
  *
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  * @author Martin Pala <martinp@tildeslash.com>
- * @version \$Id: event.c,v 1.41 2004/07/31 20:15:07 martinp Exp $
+ * @version \$Id: event.c,v 1.45 2005/01/06 20:51:49 martinp Exp $
  * @file
  */
 
@@ -88,7 +88,7 @@ static int  handle_action(Event_T, Action_T);
 void Event_post(Service_T service, long id, short state, EventAction_T action,
   char *s, ...) {
 
-  Event_T e = service->eventlist;
+  Event_T        e = service->eventlist;
 
   ASSERT(service);
   ASSERT(action);
@@ -106,6 +106,7 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
     /* Initialize event list and add first event. */
     NEW(e);
     e->id = id;
+    e->collected = time(NULL);
     e->source = service;
     e->state = state;
     e->state_changed = TRUE;
@@ -116,7 +117,7 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
       va_list ap;
 
       va_start(ap, s);
-      e->message = format(s, ap, &l);
+      e->message = Util_formatString(s, ap, &l);
       va_end(ap);
     }
     pthread_mutex_init(&e->mutex, NULL);
@@ -132,6 +133,8 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
       if(e->action == action && e->id == id)
       {
         LOCK(e->mutex)
+          e->collected = time(NULL);
+
           /* update the message */
           if(s)
           {
@@ -140,7 +143,7 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
 
             FREE(e->message);
             va_start(ap, s);
-            e->message = format(s, ap, &l);
+            e->message = Util_formatString(s, ap, &l);
             va_end(ap);
           }
 
@@ -166,6 +169,7 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
       /* Event was not found in the pending events list, we will add it. */
       NEW(e);
       e->id = id;
+      e->collected = time(NULL);
       e->source = service;
       e->state = state;
       e->state_changed = TRUE;
@@ -176,7 +180,7 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
         va_list ap;
 
         va_start(ap, s);
-        e->message = format(s, ap, &l);
+        e->message = Util_formatString(s, ap, &l);
         va_end(ap);
       }
       pthread_mutex_init(&e->mutex, NULL);
@@ -209,6 +213,34 @@ Service_T Event_get_source(Event_T E) {
 }
 
 
+/**
+ * Get the Event timestamp
+ * @param E An event object
+ * @return The Event timestamp
+ */
+time_t Event_get_collected(Event_T E) {
+
+  ASSERT(E);
+  
+  return E->collected;
+
+}
+
+
+/**
+ * Get the Event raw state
+ * @param E An event object
+ * @return The Event raw state
+ */
+short Event_get_state(Event_T E) {
+
+  ASSERT(E);
+  
+  return E->state;
+
+}
+
+
 /**
  * Get the Event type
  * @param E An event object
@@ -268,18 +300,13 @@ const char *Event_get_description(Event_T E) {
 
 
 /**
- * Get a textual description of actual event action. For instance if the
- * event type is possitive EVENT_NONEXIST, the textual description of
- * failed state related action is "restart". Likewise if the event type is
- * negative EVENT_CHECKSUM the textual description of recovery related action
- * is "alert" and so on.
+ * Get an event action id.
  * @param E An event object
- * @return A string describing the event type in clear text. If the
- * event type is not found NULL is returned.
+ * @return An action id
  */
-const char *Event_get_action_description(Event_T E) {
+short Event_get_action(Event_T E) {
 
-  int id;
+  short id;
   Action_T A;
 
   ASSERT(E);
@@ -295,7 +322,26 @@ const char *Event_get_action_description(Event_T E) {
         (A->id == ACTION_RESTART))
       )?ACTION_ALERT:A->id;
 
-  return actionnames[id];
+  return id;
+
+}
+
+
+/**
+ * Get a textual description of actual event action. For instance if the
+ * event type is possitive EVENT_NONEXIST, the textual description of
+ * failed state related action is "restart". Likewise if the event type is
+ * negative EVENT_CHECKSUM the textual description of recovery related action
+ * is "alert" and so on.
+ * @param E An event object
+ * @return A string describing the event type in clear text. If the
+ * event type is not found NULL is returned.
+ */
+const char *Event_get_action_description(Event_T E) {
+
+  ASSERT(E);
+
+  return actionnames[Event_get_action(E)];
 
 }
 
@@ -353,10 +399,12 @@ static int handle_action(Event_T E, Action_T A) {
     return TRUE;
   }
 
-  /* Alert is common action. It is send on state change only (e.g. once). */
+  /* Alert and collector event notification is common action. It is send on
+   * state change only (i.e. once) */
   if(E->state_changed || (E->id == EVENT_CHANGED))
   {
     handle_alert(E);
+    handle_collector(E);
   }
 
   switch(A->id)
