@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -56,6 +56,9 @@ static void _gcuid(Uid_T *);
 static void _gcgid(Gid_T *);
 static void _gcgrc(Generic_T *);
 static void _gcath(Auth_T *);
+static void _gc_collector(Collector_T *);
+static void _gc_url(URL_T *);
+static void _gc_request(Request_T *);
 
 
 /**
@@ -64,7 +67,7 @@ static void _gcath(Auth_T *);
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: gc.c,v 1.55 2004/08/16 20:00:30 martinp Exp $
+ *  @version \$Id: gc.c,v 1.60 2005/01/24 01:04:36 hauk Exp $
  *
  *  @file
  */
@@ -96,6 +99,9 @@ void gc() {
   if(Run.mailservers)
     _gc_mail_server(&Run.mailservers);
 
+  if(Run.collectors)
+    _gc_collector(&Run.collectors);
+
   FREE(Run.mygroup);
   FREE(Run.httpsslpem);
   FREE(Run.httpsslclientpem);
@@ -203,6 +209,12 @@ static void _gc_service(Service_T *s) {
   if((*s)->action_TIMEOUT)
     _gc_eventaction(&(*s)->action_TIMEOUT);
   
+  if((*s)->action_PID)
+    _gc_eventaction(&(*s)->action_PID);
+  
+  if((*s)->action_PPID)
+    _gc_eventaction(&(*s)->action_PPID);
+  
   if((*s)->eventlist)
     _gc_event(&(*s)->eventlist);
   
@@ -218,6 +230,37 @@ static void _gc_service(Service_T *s) {
 
 }
   
+static void _gc_request(Request_T *r) {
+  
+  ASSERT(r);
+
+  if((*r)->url)
+    _gc_url(&(*r)->url);
+#ifdef HAVE_REGEX_H
+  if ((*r)->regex)
+    regfree((*r)->regex);
+#endif
+  FREE((*r)->regex);
+  FREE(*r);
+
+}
+
+
+static void _gc_url(URL_T *url) {
+
+  ASSERT(url);
+  
+  FREE((*url)->url);
+  FREE((*url)->protocol);
+  FREE((*url)->user);
+  FREE((*url)->password);
+  FREE((*url)->hostname);
+  FREE((*url)->path);
+  FREE((*url)->query);
+  FREE(*url);
+
+}
+
 
 static void _gc_mail_server(MailServer_T *s) {
 
@@ -291,9 +334,10 @@ static void _gcppl(Port_T *p) {
 
   if((*p)->action)
     _gc_eventaction(&(*p)->action);
-
   if((*p)->generic)
     _gcgrc(&(*p)->generic);
+  if((*p)->url_request)
+    _gc_request(&(*p)->url_request);
 
   FREE((*p)->address);
   FREE((*p)->request);
@@ -302,7 +346,6 @@ static void _gcppl(Port_T *p) {
   FREE((*p)->SSL.certmd5);
   FREE((*p)->request_checksum);
   FREE(*p);
-
 }
 
 
@@ -486,3 +529,18 @@ static void _gcath(Auth_T *c) {
   
 }
 
+
+static void _gc_collector(Collector_T *recv) {
+
+  ASSERT(recv);
+
+  if((*recv)->next)
+    _gc_collector(&(*recv)->next);
+
+  _gc_url(&(*recv)->url);
+
+  FREE((*recv)->ssl.certmd5);
+  FREE(*recv);
+
+}
+
