@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -45,7 +45,7 @@ static unsigned char decode(char c);
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: base64.c,v 1.14 2004/04/04 08:08:11 hauk Exp $
+ *  @version \$Id: base64.c,v 1.16 2005/01/28 10:39:33 martinp Exp $
  *
  *  @file
  */
@@ -132,7 +132,7 @@ int decode_base64(unsigned char *dest, const char *src) {
   
     unsigned char *p= dest;
     int k, l= strlen(src)+1;
-    unsigned char *buf= xmalloc(l);
+    unsigned char *buf= xcalloc(sizeof(unsigned char), l);
 
     
     /* Ignore non base64 chars as per the POSIX standard */
