@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -74,6 +74,7 @@
 /* URL Commands supported */
 #define HOME        "/"
 #define STOP        "/_stop"
+#define VALIDATE    "/_validate"
 #define TEST        "/_monit"
 #define ABOUT       "/_about"
 #define PIXEL       "/_pixel"
@@ -127,13 +128,10 @@ static void print_service_params_size(HttpResponse, Service_T);
 static void print_service_params_checksum(HttpResponse, Service_T);
 static void print_service_params_process(HttpResponse, Service_T);
 static void print_status(HttpResponse, int);
-static void status_start(HttpResponse, int);
-static void status_stop(HttpResponse, int);
-static void status_service_xml(Service_T, HttpResponse);
-static void status_service_text(Service_T, HttpResponse);
+static void status_system_txt(HttpResponse);
+static void status_service_txt(Service_T, HttpResponse);
 static char *get_service_status_html(Service_T);
 static char *get_service_status_text(Service_T);
-static int  check_service_status(Service_T);
 
 
 /**
@@ -146,7 +144,7 @@ static int  check_service_status(Service_T);
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: cervlet.c,v 1.162 2004/09/14 19:00:46 martinp Exp $
+ *  @version \$Id: cervlet.c,v 1.184 2005/02/20 23:14:46 hauk Exp $
  *
  *  @file
  */
@@ -211,11 +209,19 @@ static void doGet(HttpRequest req, HttpResponse res) {
 		 "The monit http server is stopped");
       stop_httpd();
     }
+  } else if(ACTION(VALIDATE)) {
+    if(is_readonly(req)) {
+      send_error(res, SC_FORBIDDEN,
+		 "You do not have sufficent privilegs to access this page");
+    } else {
+      do_wakeupcall();
+      send_redirect(res, HOME);
+    }
   } else if(ACTION(PIXEL)) {
     printPixel(res);
   } else if(ACTION(STATUS)) {
     const char *format= get_parameter(req, "format");
-    if(format && starts_with(format, "xml"))
+    if(format && Util_startsWith(format, "xml"))
       print_status(res, XML_STATUS);
     else {
       /* Text status output is default */
@@ -249,7 +255,7 @@ static void is_monit_running(HttpRequest req, HttpResponse res) {
 
 static void do_home(HttpRequest req, HttpResponse res) {
 
-  char *uptime= get_uptime(get_process_uptime(Run.pidfile), "&nbsp;");
+  char *uptime= Util_getUptime(Util_getProcessUptime(Run.pidfile), "&nbsp;");
  
   HEAD("", Run.polltime)
   out_print(res,
@@ -270,7 +276,9 @@ static void do_home(HttpRequest req, HttpResponse res) {
 
   FREE(uptime);
   
-  do_home_system(req, res);
+  if(Run.doprocess) {
+    do_home_system(req, res);
+  }
   do_home_process(req, res);
   do_home_device(req, res);
   do_home_file(req, res);
@@ -284,16 +292,14 @@ static void do_home(HttpRequest req, HttpResponse res) {
 
 static void do_about(HttpRequest req, HttpResponse res) {
 
-  HEAD("_about", 1000)
-
   out_print(res,
     "<html><head><title>about monit</title><body bgcolor=white>"
     "<br><br><center><a href='http://www.tildeslash.com/monit/'><font size=+2>"
     "monit " VERSION "</font></a></center><br><br>");
   out_print(res,
     "<ul>"
-    "<li>Copyright &copy; 2000-2004 by <a "
-    "href=\"http://www.tildeslash.com/monit/who.html\">the monit "
+    "<li>Copyright &copy; 2000-2005 by <a "
+    "href=\"http://www.tildeslash.com/monit/who.php\">the monit "
     "project group</a>. All Rights Reserved.<br> </small><p>"
     "<li>Portions of this software are copyright &copy; 1995, 1996 "
     "<a href='http://www.gnu.org/'>Free Software Foundation, Inc.</a></ul>");
@@ -310,11 +316,14 @@ static void do_about(HttpRequest req, HttpResponse res) {
     "This program is distributed in the hope that it will be useful, but "
     "WITHOUT ANY WARRANTY; without even the implied warranty of "
     "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-    "<a href='http://www.tildeslash.com/gpl.html'>GNU "
+    "<a href='http://www.gnu.org/licenses/gpl.html'>GNU "
     "General Public License</a> for more details."
     "<p><br><center><p><i>Please consider making a "
-    "<a class=grey href=\"http://www.tildeslash.com/monit/index.html#support\">"
+    "<a class=grey href=\"http://www.tildeslash.com/monit/donate.php\">"
     "donation</a> and support our continued work with monit.</i></center>");
+  out_print(res,
+   "<p align=left><form method=GET action='/'><input type=submit"
+   " value='<<&nbsp; Back'></form></p>");
 
   FOOT
 
@@ -356,7 +365,25 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
   out_print(res,
 	    "<tr><td>Use syslog</td><td>%s</td></tr>",
 	    Run.use_syslog?"True":"False");
-  
+
+  if(Run.collectors) {
+    Collector_T c= Run.collectors;
+    out_print(res, "<tr><td>Collector server(s)</td><td>");
+    for(c= Run.collectors; c; c= c->next)
+    {
+      out_print(res,
+        "%s with timeout %d seconds%s%s%s%s</td></tr>%s",
+        c->url->url,
+        c->timeout,
+        c->ssl.use_ssl?" ssl version ":"",
+        c->ssl.use_ssl?sslnames[c->ssl.version]:"",
+        c->ssl.certmd5?" server cert md5 sum ":"",
+        c->ssl.certmd5?c->ssl.certmd5:"",
+        c->next?"<tr><td>&nbsp;</td><td>":"");
+    }
+    printf("\n");
+  }
+
   out_print(res, "<tr><td>Mail server(s)</td><td>");
   if(Run.mailservers) {
     MailServer_T mta= Run.mailservers;
@@ -389,7 +416,7 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
   out_print(res,
 	    "<tr><td>httpd portnumber</td><td>%d</td></tr>", Run.httpdport);
   out_print(res,
-	    "<tr><td>httpd signature</td><td>%d</td></tr>",
+	    "<tr><td>httpd signature</td><td>%s</td></tr>",
 	    Run.httpdsig?"True":"False");
   out_print(res,
 	    "<tr><td>Use ssl encryption</td><td>%s</td></tr>",
@@ -418,10 +445,10 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
   
   out_print(res,
 	    "<tr><td>httpd auth. style</td><td>%s</td></tr>",
-	    (Run.credentials!=NULL)&&has_hosts_allow()?
-	    "Basic Authentication and Host allow list":
+	    (Run.credentials!=NULL)&&(has_hosts_allow())?
+	    "Basic Authentication and Host/Net allow list":
 	    (Run.credentials!=NULL)?"Basic Authentication":
-	    has_hosts_allow()?"Host allow list":
+	    (has_hosts_allow())?"Host/Net allow list":
 	    "No authentication");
 
   print_alerts(res, Run.maillist);
@@ -429,20 +456,47 @@ static void do_runtime(HttpRequest req, HttpResponse res) {
   out_print(res,"</table>");
 
   if(!is_readonly(req)) {
-    out_print(res, "<table cellspacing=16><tr nowrap><td><font size=+1>"
-	      "<font color='#f0000'>Stop monit http server?</font></font>"
-	      "<td align=right><form method=GET action=%s>"
-	      "<input type=submit value=Go style='font-size: 12pt'></font>"
-	      "</form></td>", STOP);
+    out_print(res,
+      "<table cellspacing=16>"
+      "<tr nowrap>");
+    out_print(res,
+      "<td>"
+      "<font size=+1 color='#f0000'>Stop monit http server?</font>"
+      "</td>"
+      "<td align=right>"
+      "<form method=GET action=%s>"
+      "<input type=submit value=Go style='font-size: 12pt'></font>"
+      "</form>"
+      "</td>",
+      STOP);
+
+    out_print(res,
+      "<td>"
+      "<font size=+1>Force validate now?</font>"
+      "</td>"
+      "<td align=right>"
+      "<form method=GET action=%s>"
+      "<input type=submit value=Go style='font-size: 12pt'></font>"
+      "</form>"
+      "</td>",
+      VALIDATE);
+
     if(Run.dolog && !Run.use_syslog) {
-      out_print(res, "<td><font size=+1>"
-		"View monit logfile?</font>"
-		"<td align=right><form method=GET action=%s>"
-		"<input type=submit value=Go style='font-size: 12pt'></font>"
-		"</form></td>", VIEWLOG);
+      out_print(res,
+      "<td>"
+      "<font size=+1>View monit logfile?</font>"
+      "</td>"
+      "<td align=right>"
+      "<form method=GET action=%s>"
+      "<input type=submit value=Go style='font-size: 12pt'></font>"
+      "</form>"
+      "</td>",
+      VIEWLOG);
     }
+    out_print(res,
+      "</tr>"
+      "</table>");
   }
-  out_print(res, "</tr></table>");
   
   FOOT
 
@@ -468,12 +522,14 @@ static void do_viewlog(HttpRequest req, HttpResponse res) {
       FILE *f= fopen(Run.logfile, "r");
       if(f) {
 	
+        #define BUFSIZE 8192
+
 	int n;
-	char buf[8192];
+	char buf[BUFSIZE+1];
 	
 	out_print(res, "<br><p><form><textarea cols=80 rows=30>");
 	
-	while((n= fread(buf, sizeof(char), 8192, f)) > 0) {
+	while((n= fread(buf, sizeof(char), BUFSIZE, f)) > 0) {
 	  
 	  buf[n]= 0;
 	  out_print(res, "%s", buf);
@@ -521,9 +577,14 @@ static void handle_action(HttpRequest req, HttpResponse res) {
   char *name= req->url;
   const char *action= get_parameter(req, "action");
   
-  if(exist_service(++name)) {
+  if(Util_existService(++name)) {
 
-    Service_T s= get_service(name);
+    Service_T s= Util_getService(name);
+
+    if(s == NULL) {
+      send_error(res, SC_BAD_REQUEST, "There is no service by that name");
+      return;
+    }
 
     if(!action) {
 
@@ -545,13 +606,13 @@ static void handle_action(HttpRequest req, HttpResponse res) {
 		/* Wait for the service to start (or fail) */
 		int max_tries= Run.polltime;
 		while(max_tries-- && !Run.stopped) {
-		  if(is_process_running(s))
+		  if(Util_isProcessRunning(s))
 		      break;
 		  sleep(1);
 		}
 	      }
 	  END_LOCK;
-	  if(s->type==TYPE_PROCESS && !is_process_running(s)) {
+	  if(s->type==TYPE_PROCESS && !Util_isProcessRunning(s)) {
 	    send_error(res, SC_INTERNAL_SERVER_ERROR,
 		       "Could not start the service");
 	    goto quit;
@@ -579,13 +640,13 @@ static void handle_action(HttpRequest req, HttpResponse res) {
 		/* Wait for the service to restart (or fail) */
 		int max_tries= Run.polltime;
 		while(max_tries-- && !Run.stopped) {
-		  if(is_process_running(s))
+		  if(Util_isProcessRunning(s))
 		      break;
 		  sleep(1);
 		}
 	      }
 	  END_LOCK;
-	  if(s->type==TYPE_PROCESS && !is_process_running(s)) {
+	  if(s->type==TYPE_PROCESS && !Util_isProcessRunning(s)) {
 	    send_error(res, SC_INTERNAL_SERVER_ERROR,
 		       "Could not restart the service");
 	    goto quit;
@@ -627,6 +688,8 @@ static void do_service(HttpRequest req, HttpResponse res, Service_T s) {
   char *status;
   char time[STRLEN];
 
+  ASSERT(s);
+
   LOCK(s->mutex)
 
     HEAD(s->name, Run.polltime)
@@ -859,7 +922,7 @@ static void do_home_process(HttpRequest req, HttpResponse res) {
       status);
     FREE(status);
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res,
         "<td align=\"right\">-</td>");
@@ -872,7 +935,7 @@ static void do_home_process(HttpRequest req, HttpResponse res) {
 
     } else {
 
-      char *uptime= get_uptime(s->inf->uptime, "&nbsp;");
+      char *uptime= Util_getUptime(s->inf->uptime, "&nbsp;");
       out_print(res,
         "<td align=\"right\">%s</td>", uptime);
       FREE(uptime);
@@ -939,7 +1002,7 @@ static void do_home_device(HttpRequest req, HttpResponse res) {
       status);
     FREE(status);
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res,
 	"<td align=\"right\">- [-]</td>"
@@ -949,18 +1012,15 @@ static void do_home_device(HttpRequest req, HttpResponse res) {
       
       out_print(res,
 	"<td align=\"right\">%.1f%% [%.1f&nbsp;MB]</td>",
-	(float) 100 * (s->inf->f_blocks - s->inf->f_blocksfree) /
-                s->inf->f_blocks,
-	(float) (s->inf->f_blocks - s->inf->f_blocksfree) / 1048576 *
-                s->inf->f_bsize);
+        s->inf->space_percent/10.,
+	(float)s->inf->space_total / (float)1048576 * (float)s->inf->f_bsize);
 
       if(s->inf->f_files > 0) {
 
         out_print(res,
 	  "<td align=\"right\">%.1f%% [%ld&nbsp;objects]</td>",
-	  (float) 100 * (s->inf->f_files - s->inf->f_filesfree) /
-                  s->inf->f_files,
-	  s->inf->f_files - s->inf->f_filesfree);
+          s->inf->inode_percent/10.,
+	  s->inf->inode_total);
 
       } else {
 
@@ -1023,7 +1083,7 @@ static void do_home_file(HttpRequest req, HttpResponse res) {
       status);
     FREE(status);
     
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
       
       out_print(res,
 	"<td align=\"right\">-</td>"
@@ -1095,7 +1155,7 @@ static void do_home_directory(HttpRequest req, HttpResponse res) {
       status);
     FREE(status);
     
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
       
       out_print(res,
 	"<td align=\"right\">-</td>"
@@ -1164,7 +1224,7 @@ static void do_home_host(HttpRequest req, HttpResponse res) {
       status);
     FREE(status);
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res,
         "<td align=\"right\">-</td>");
@@ -1274,7 +1334,7 @@ static void print_buttons(HttpRequest req, HttpResponse res, Service_T s) {
 
   if(is_readonly(req)) {
     /*
-     * A read-only REMOTE_USER will not get access to the buttons
+     * A read-only REMOTE_USER does not get access to these buttons
      */
     return;
   }
@@ -1451,23 +1511,39 @@ static void print_service_rules_device(HttpResponse res, Service_T s) {
 	
       if(dl->resource == RESOURCE_ID_INODE) {
 	  
-        out_print(res,
-	  "<tr><td>Inodes usage limit</td><td>If %s %ld %s "
-	  "then %s else if recovered then %s</td></tr>",
-	  operatornames[dl->operator],
-	  (dl->limit_absolute > -1)?dl->limit_absolute:dl->limit_percent,
-	  (dl->limit_absolute > -1)?"":"%",
-	  actionnames[a->failed->id], actionnames[a->passed->id]);
+        if(dl->limit_absolute > -1) {
+          out_print(res,
+	    "<tr><td>Inodes usage limit</td><td>If %s %ld "
+	    "then %s else if recovered then %s</td></tr>",
+	    operatornames[dl->operator],
+	    dl->limit_absolute,
+	    actionnames[a->failed->id], actionnames[a->passed->id]);
+        } else {
+          out_print(res,
+	    "<tr><td>Inodes usage limit</td><td>If %s %.1f%% "
+	    "then %s else if recovered then %s</td></tr>",
+	    operatornames[dl->operator],
+	    dl->limit_percent/10.,
+	    actionnames[a->failed->id], actionnames[a->passed->id]);
+        }
 	  
       } else if(dl->resource == RESOURCE_ID_SPACE) {
 	  
-        out_print(res,
-	  "<tr><td>Space usage limit</td><td>If %s %ld %s "
-	  "then %s else if recovered then %s</td></tr>",
-          operatornames[dl->operator],
-	  (dl->limit_absolute > -1)?dl->limit_absolute:dl->limit_percent,
-	  (dl->limit_absolute > -1)?"blocks":"%",
-	  actionnames[a->failed->id], actionnames[a->passed->id]);
+        if(dl->limit_absolute > -1) {
+          out_print(res,
+	    "<tr><td>Space usage limit</td><td>If %s %ld blocks "
+	    "then %s else if recovered then %s</td></tr>",
+            operatornames[dl->operator],
+	    dl->limit_absolute,
+	    actionnames[a->failed->id], actionnames[a->passed->id]);
+        } else {
+          out_print(res,
+	    "<tr><td>Space usage limit</td><td>If %s %.1f%% "
+	    "then %s else if recovered then %s</td></tr>",
+            operatornames[dl->operator],
+	    dl->limit_percent/10.,
+	    actionnames[a->failed->id], actionnames[a->passed->id]);
+        }
       }
     }
   }
@@ -1532,6 +1608,13 @@ static void print_service_rules_checksum(HttpResponse res, Service_T s) {
 
 static void print_service_rules_process(HttpResponse res, Service_T s) {
 
+  if(s->type == TYPE_PROCESS) {
+    out_print(res, "<tr><td>Pid</td><td>If changed then %s</td></tr>\n",
+      actionnames[s->action_PID->failed->id]);
+    out_print(res, "<tr><td>Ppid</td><td>If changed then %s</td></tr>\n",
+      actionnames[s->action_PPID->failed->id]);
+  }
+
   if(s->resourcelist) {
 
     Resource_T    q;
@@ -1647,7 +1730,7 @@ static void print_service_params_port(HttpResponse res, Service_T s) {
 
     Port_T p;
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       for(p= s->portlist; p; p= p->next)
         if(p->family == AF_INET) {
@@ -1702,7 +1785,7 @@ static void print_service_params_icmp(HttpResponse res, Service_T s) {
 
     Icmp_T i;
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       for(i= s->icmplist; i; i= i->next)
         out_print(res, "<tr><td>ICMP Response time</td><td>-</td></tr>");
@@ -1731,7 +1814,7 @@ static void print_service_params_perm(HttpResponse res, Service_T s) {
      s->type == TYPE_DIRECTORY ||
      s->type == TYPE_DEVICE) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res, "<tr><td>Permission</td><td>-</font></td></tr>");
 
@@ -1753,7 +1836,7 @@ static void print_service_params_uid(HttpResponse res, Service_T s) {
      s->type == TYPE_DIRECTORY ||
      s->type == TYPE_DEVICE) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res, "<tr><td>UID</td><td>-</font></td></tr>");
 
@@ -1775,7 +1858,7 @@ static void print_service_params_gid(HttpResponse res, Service_T s) {
      s->type == TYPE_DIRECTORY ||
      s->type == TYPE_DEVICE) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res, "<tr><td>GID</td><td>-</font></td></tr>");
 
@@ -1795,7 +1878,7 @@ static void print_service_params_timestamp(HttpResponse res, Service_T s) {
 
   if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res, "<tr><td>Timestamp</td><td>-</font></td></tr>");
 
@@ -1817,12 +1900,12 @@ static void print_service_params_device(HttpResponse res, Service_T s) {
 
   if(s->type == TYPE_DEVICE) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res,
         "<tr><td>Blocks total</td><td>-</td></tr>");
       out_print(res,
-        "<tr><td>Blocks free for non superuser</td><td>-</font></td></tr>");
+        "<tr><td>Blocks free for non superuser</td><td>-</td></tr>");
       out_print(res,
         "<tr><td>Blocks free total</td><td>-</td></tr>");
       out_print(res,
@@ -1830,7 +1913,7 @@ static void print_service_params_device(HttpResponse res, Service_T s) {
       out_print(res,
         "<tr><td>Inodes total</td><td>-</td></tr>");
       out_print(res,
-        "<tr><td>Inodes free</td><td>-</font></td></tr>");
+        "<tr><td>Inodes free</td><td>-</td></tr>");
 
     } else {
 
@@ -1842,15 +1925,15 @@ static void print_service_params_device(HttpResponse res, Service_T s) {
         "<tr><td>Blocks free for non superuser</td>"
         "<td>%ld [%.1f MB] [%.1f%%]</td></tr>",
         s->inf->f_blocksfree,
-        (float) s->inf->f_blocksfree/1048576*s->inf->f_bsize,
-        (float) 100*s->inf->f_blocksfree/s->inf->f_blocks);
+        (float)s->inf->f_blocksfree / (float)1048576 * (float)s->inf->f_bsize,
+        (float)100 * (float)s->inf->f_blocksfree / (float)s->inf->f_blocks);
       out_print(res,
         "<tr><td>Blocks free total</td>"
         "<td><font%s>%ld [%.1f MB] [%.1f%%]</font></td></tr>",
         (s->error & EVENT_RESOURCE)?" color='#ff0000'":"",
         s->inf->f_blocksfreetotal,
-        (float) s->inf->f_blocksfreetotal/1048576*s->inf->f_bsize,
-        (float) 100*s->inf->f_blocksfreetotal/s->inf->f_blocks);
+        (float)s->inf->f_blocksfreetotal / (float)1048576 * (float)s->inf->f_bsize,
+        (float)100 * (float)s->inf->f_blocksfreetotal / (float)s->inf->f_blocks);
       out_print(res,
         "<tr><td>Block size</td><td>%ld B</td></tr>", s->inf->f_bsize);
 
@@ -1862,7 +1945,7 @@ static void print_service_params_device(HttpResponse res, Service_T s) {
           "<tr><td>Inodes free</td><td><font%s>%ld [%.1f%%]</font></td></tr>",
           (s->error & EVENT_RESOURCE)?" color='#ff0000'":"",
           s->inf->f_filesfree,
-          (float) 100*s->inf->f_filesfree/s->inf->f_files);
+          (float)100 * (float)s->inf->f_filesfree / (float)s->inf->f_files);
 
       }
     }
@@ -1874,7 +1957,7 @@ static void print_service_params_size(HttpResponse res, Service_T s) {
 
   if(s->type == TYPE_FILE) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res,
         "<tr><td>Size</td><td>-</font></td></tr>");
@@ -1895,15 +1978,16 @@ static void print_service_params_checksum(HttpResponse res, Service_T s) {
 
   if(s->type == TYPE_FILE && s->checksum) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res, "<tr><td>Checksum</td><td>-</font></td></tr>");
 
     } else {
 
       out_print(res,
-        "<tr><td>Checksum</td><td><font%s>%s</font></td></tr>",
-        (s->error & EVENT_CHECKSUM)?" color='#ff0000'":"", s->inf->cs_sum);
+        "<tr><td>Checksum</td><td><font%s>%s(%s)</font></td></tr>",
+        (s->error & EVENT_CHECKSUM)?" color='#ff0000'":"", s->inf->cs_sum,
+        checksumnames[s->checksum->type]);
 
     }
   }
@@ -1914,7 +1998,7 @@ static void print_service_params_process(HttpResponse res, Service_T s) {
 
   if(s->type == TYPE_PROCESS) {
 
-    if(!check_service_status(s)) {
+    if(!Util_hasServiceStatus(s)) {
 
       out_print(res,
         "<tr><td>Process id </td><td>-</td></tr>"
@@ -1941,7 +2025,7 @@ static void print_service_params_process(HttpResponse res, Service_T s) {
         "<tr><td>Parent process id </td><td>%d</td></tr>",
         s->inf->ppid);
 
-      uptime= get_uptime(s->inf->uptime, "&nbsp;");
+      uptime= Util_getUptime(s->inf->uptime, "&nbsp;");
       out_print(res,
         "<tr><td>Process uptime</td><td>%s</td></tr>",
         uptime);
@@ -1979,7 +2063,8 @@ static void print_service_params_process(HttpResponse res, Service_T s) {
 static int is_readonly(HttpRequest req) {
 
   if(req->remote_user) {
-    return ((Auth_T)get_user_credentials(req->remote_user))->is_readonly;
+    Auth_T user_creds = Util_getUserCredentials(req->remote_user);
+    return ( user_creds?user_creds->is_readonly:TRUE );
   }
 
   return FALSE;
@@ -1990,433 +2075,211 @@ static int is_readonly(HttpRequest req) {
 /* ----------------------------------------------------------- Status output */
 
 
+/* Print status in the given format. Text status is default. */
 static void print_status(HttpResponse res, int format) {
 
   Service_T s;
-  void (*status_service)(Service_T, HttpResponse);
 
-  if(format==XML_STATUS) {
+  if(format==XML_STATUS)
+  {
+    char *D;
+
     set_content_type(res, "text/xml");
-    status_service= status_service_xml;
-  } else {
-    /* Text status is default */
+    D = status_xml(NULL);
+    out_print(res, "%s", D);
+    FREE(D);
+  }
+  else
+  {
     set_content_type(res, "text/plain");
-    status_service= status_service_text;
-  }
-
-  status_start(res, format);
-  for(s= servicelist_conf; s; s= s->next_conf) {
-    status_service(s, res);
-  }
-  status_stop(res, format);
-
-}
-
-
-static void status_start(HttpResponse res, int format) {
-
-  time_t uptime= get_process_uptime(Run.pidfile);
-
-  if(format==XML_STATUS)
-  {
-    out_print(res,
-     "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\r\n"
-     "<monit>\r\n"
-     "\t<server>\r\n"
-     "\t\t<version>%s</version>\r\n"
-     "\t\t<uptime>%ld</uptime>\r\n"
-     "\t</server>\r\n", 
-     VERSION,
-     (long)uptime);
-
-    out_print(res,
-     "\t<system>\r\n"
-     "\t\t<hostname>%s</hostname>\r\n"
-     "\t\t<load>\r\n"
-     "\t\t\t<avg01>%.2f</avg01>\r\n"
-     "\t\t\t<avg05>%.2f</avg05>\r\n"
-     "\t\t\t<avg15>%.2f</avg15>\r\n"
-     "\t\t</load>\r\n"
-     "\t\t<cpu>\r\n"
-     "\t\t\t<user>%.1f</user>\r\n"
-     "\t\t\t<system>%.1f</system>\r\n"
-  #ifdef HAVE_CPU_WAIT
-     "\t\t\t<wait>%.1f</wait>\r\n"
-  #endif
-     "\t\t</cpu>\r\n"
-     "\t\t<memory>\r\n"
-     "\t\t\t<kilobyte>%ld</kilobyte>\r\n"
-     "\t\t\t<percent>%.1f</percent>\r\n"
-     "\t\t</memory>\r\n"
-     "\t\t<collected>%ld</collected>\r\n"
-     "\t</system>\r\n", 
-     Run.localhostname,
-     systeminfo.loadavg[0],
-     systeminfo.loadavg[1],
-     systeminfo.loadavg[2],
-     systeminfo.total_cpu_user_percent/10.,
-     systeminfo.total_cpu_syst_percent/10.,
-  #ifdef HAVE_CPU_WAIT
-     systeminfo.total_cpu_wait_percent/10.,
-  #endif
-     systeminfo.total_mem_kbyte,
-     systeminfo.total_mem_percent/10.,
-     systeminfo.collected);
-  }
-  else /* Text status is default */
-  {
-    char *_uptime;
-    char  time[STRLEN];
-
-    _uptime= get_uptime(uptime, " ");
-    out_print(res,
-      "The monit daemon %s uptime: %s\n\n", VERSION, _uptime);
-    FREE(_uptime);
-
-    ctime_r(&systeminfo.collected, time);
-    out_print(res,
-      "System '%s'\n"
-      "  %-33s [%.2f] [%.2f] [%.2f]\n"
-      "  %-33s %.1f%%us %.1f%%sy"
-  #ifdef HAVE_CPU_WAIT
-      " %.1f%%wa"
-  #endif
-      "\n"
-      "  %-33s %ld kB [%.1f%%]\n"
-      "  %-33s %s",
-      Run.localhostname,
-      "load average",
-      systeminfo.loadavg[0],
-      systeminfo.loadavg[1],
-      systeminfo.loadavg[2],
-      "cpu",
-      systeminfo.total_cpu_user_percent/10.,
-      systeminfo.total_cpu_syst_percent/10.,
-  #ifdef HAVE_CPU_WAIT
-      systeminfo.total_cpu_wait_percent/10.,
-  #endif
-      "memory usage",
-      systeminfo.total_mem_kbyte,
-      systeminfo.total_mem_percent/10.,
-      "data collected",
-      time);
-
-    out_print(res, "\n");
+    if(Run.doprocess) {
+      status_system_txt(res);
+    }
+    for(s= servicelist_conf; s; s= s->next_conf)
+    {
+      status_service_txt(s, res);
+    }
   }
 }
 
 
-static void status_stop(HttpResponse res, int format) {
- 
-  if(format==XML_STATUS)
-  {
-    out_print(res, "</monit>\r\n");
-  }
-}
+static void status_system_txt(HttpResponse res) {
 
+  char *uptime;
+  char  time[STRLEN];
 
-static void status_service_xml(Service_T s, HttpResponse res) {
-
+  uptime= Util_getUptime(Util_getProcessUptime(Run.pidfile), " ");
   out_print(res,
-    "\t<service>\r\n"
-    "\t\t<type>%d</type>\r\n"
-    "\t\t<name>%s</name>\r\n"
-    "\t\t<status>%llu</status>\r\n"
-    "\t\t<monitor>%d</monitor>\r\n",
-    s->type, 
-    s->name,
-    s->error,
-    s->monitor);
-  if(check_service_status(s))
-  {
-    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY || s->type == TYPE_DEVICE)
-    {
-      out_print(res,
-        "\t\t<mode>%o</mode>\r\n"
-        "\t\t<uid>%d</uid>\r\n"
-        "\t\t<gid>%d</gid>\r\n",
-        s->inf->st_mode & 07777,
-        (int)s->inf->st_uid,
-        (int)s->inf->st_gid);
-    }
-    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY)
-    {
-      out_print(res,
-        "\t\t<timestamp>%ld</timestamp>\r\n",
-        (long)s->inf->timestamp);
-    }
-    if(s->type == TYPE_FILE)
-    {
-      out_print(res,
-        "\t\t<size>%lu</size>\r\n",
-        (unsigned long) s->inf->st_size);
-      if(s->checksum)
-      {
-        out_print(res,
-          "\t\t<checksum>%s</checksum>\r\n",
-          s->inf->cs_sum);
-      }
-    }
-    if(s->type == TYPE_DEVICE)
-    {
-      out_print(res,
-        "\t\t<block>\r\n"
-        "\t\t\t<size>%ld</size>\r\n"
-        "\t\t\t<total>%ld</total>\r\n"
-        "\t\t\t<free>%ld</free>\r\n"
-        "\t\t\t<freetotal>%ld</freetotal>\r\n"
-        "\t\t</block>\r\n",
-        s->inf->f_bsize,
-        s->inf->f_blocks,
-        s->inf->f_blocksfree,
-        s->inf->f_blocksfreetotal);
-      if(s->inf->f_files > 0)
-      {
-        out_print(res,
-          "\t\t<inode>\r\n"
-          "\t\t\t<total>%ld</total>\r\n"
-          "\t\t\t<free>%ld</free>\r\n"
-          "\t\t</inode>\r\n",
-          s->inf->f_files,
-          s->inf->f_filesfree);
-      }
-    }
-    if(s->type == TYPE_PROCESS)
-    {
-      out_print(res,
-        "\t\t<pid>%d</pid>\r\n"
-        "\t\t<ppid>%d</ppid>\r\n"
-        "\t\t<uptime>%ld</uptime>\r\n",
-        s->inf->pid,
-        s->inf->ppid,
-        (long)s->inf->uptime);
-      if(Run.doprocess)
-      {
-        out_print(res,
-          "\t\t<children>%d</children>\r\n"
-          "\t\t<memory>\r\n"
-          "\t\t\t<kilobyte>%ld</kilobyte>\r\n"
-          "\t\t\t<kilobytetotal>%ld</kilobytetotal>\r\n"
-          "\t\t\t<percent>%.1f</percent>\r\n"
-          "\t\t\t<percenttotal>%.1f</percenttotal>\r\n"
-          "\t\t</memory>\r\n"
-          "\t\t<cpu>\r\n"
-          "\t\t\t<percent>%.1f</percent>\r\n"
-          "\t\t\t<percenttotal>%.1f</percenttotal>\r\n"
-          "\t\t</cpu>\r\n",
-          s->inf->children,
-          s->inf->mem_kbyte,
-          s->inf->total_mem_kbyte,
-          s->inf->mem_percent/10.0,
-          s->inf->total_mem_percent/10.0,
-          s->inf->cpu_percent/10.0,
-          s->inf->total_cpu_percent/10.0);
-      }
-    }
-    if(s->type == TYPE_HOST && s->icmplist)
-    {
-      Icmp_T i;
-      for(i= s->icmplist; i; i= i->next)
-      {
-        out_print(res,
-          "\t\t<icmp>\r\n"
-          "\t\t\t<type>%s</type>\r\n"
-          "\t\t\t<responsetime>%.3f</responsetime>\r\n"
-          "\t\t</icmp>\r\n",
-          icmpnames[i->type],
-          i->is_available?i->response:-1.);
-      }
-    }
-    if((s->type == TYPE_HOST || s->type == TYPE_PROCESS) && s-> portlist)
-    {
-      Port_T p;
-      for(p= s->portlist; p; p= p->next)
-      {
-        if(p->family == AF_INET)
-        {
-          out_print(res,
-            "\t\t<port>\r\n"
-            "\t\t\t<target>%s:%d:%s:%s:%s</target>\r\n"
-            "\t\t\t<responsetime>%.3f</responsetime>\r\n"
-            "\t\t</port>\r\n",
-            p->hostname,
-            p->port,
-            p->request?p->request:"",
-            p->SSL.use_ssl?"SSL":"",
-            p->protocol->name,
-            p->is_available?p->response:-1.);
-            
-        }
-        else if(p->family == AF_UNIX)
-        {
-          out_print(res,
-            "\t\t<unix>\r\n"
-            "\t\t\t<target>%s:%s</target>\r\n"
-            "\t\t\t<responsetime>%.3f</responsetime>\r\n"
-            "\t\t</unix>\r\n",
-            p->pathname,
-            p->protocol->name,
-            p->is_available?p->response:-1.);
-        }
-      }
-    }
-  }
+    "The monit daemon %s uptime: %s\n\n", VERSION, uptime);
+  FREE(uptime);
+
+  ctime_r(&systeminfo.collected, time);
   out_print(res,
-    "\t\t<collected>%ld</collected>\r\n"
-    "\t</service>\r\n",
-    s->collected);
+    "System '%s'\n"
+    "  %-33s [%.2f] [%.2f] [%.2f]\n"
+    "  %-33s %.1f%%us %.1f%%sy"
+  #ifdef HAVE_CPU_WAIT
+    " %.1f%%wa"
+  #endif
+    "\n"
+    "  %-33s %ld kB [%.1f%%]\n"
+    "  %-33s %s",
+    Run.localhostname,
+    "load average",
+    systeminfo.loadavg[0],
+    systeminfo.loadavg[1],
+    systeminfo.loadavg[2],
+    "cpu",
+    systeminfo.total_cpu_user_percent/10.,
+    systeminfo.total_cpu_syst_percent/10.,
+  #ifdef HAVE_CPU_WAIT
+    systeminfo.total_cpu_wait_percent/10.,
+  #endif
+    "memory usage",
+    systeminfo.total_mem_kbyte,
+    systeminfo.total_mem_percent/10.,
+    "data collected",
+    time);
+
+  out_print(res, "\n");
 
 }
 
 
-static void status_service_text(Service_T s, HttpResponse res) {
-
+static void status_service_txt(Service_T s, HttpResponse res) {
   char  time[STRLEN];
   char *status;
-
   status= get_service_status_text(s);
   out_print(res,
-    "%s '%s'\n"
-    "  %-33s %s\n"
-    "  %-33s %s\n",
-    servicetypes[s->type], s->name,
-    "status", status,
-    "monitoring status", monitornames[s->monitor]);
+	    "%s '%s'\n"
+	    "  %-33s %s\n"
+	    "  %-33s %s\n",
+	    servicetypes[s->type], s->name,
+	    "status", status,
+	    "monitoring status", monitornames[s->monitor]);
   FREE(status);
-
-  if(check_service_status(s))
-  {
-    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY || s->type == TYPE_DEVICE)
-    {
+  if(Util_hasServiceStatus(s)) {
+    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY || 
+       s->type == TYPE_DEVICE) {
       out_print(res,
-        "  %-33s %o\n"
-        "  %-33s %d\n"
-        "  %-33s %d\n",
-        "permission", s->inf->st_mode & 07777,
-        "uid", (int)s->inf->st_uid,
-        "gid", (int)s->inf->st_gid);
+		"  %-33s %o\n"
+		"  %-33s %d\n"
+		"  %-33s %d\n",
+		"permission", s->inf->st_mode & 07777,
+		"uid", (int)s->inf->st_uid,
+		"gid", (int)s->inf->st_gid);
     }
-    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY)
-    {
+    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY) {
       ctime_r(&s->inf->timestamp, time);
       out_print(res,
-        "  %-33s %s",
-        "timestamp", time);
+		"  %-33s %s",
+		"timestamp", time);
     }
-    if(s->type == TYPE_FILE)
-    {
+    if(s->type == TYPE_FILE) {
       out_print(res,
-        "  %-33s %lu B\n",
-        "size", (unsigned long) s->inf->st_size);
-      if(s->checksum)
-      {
-        out_print(res,
-          "  %-33s %s\n",
-          "checksum", s->inf->cs_sum);
+		"  %-33s %lu B\n",
+		"size", (unsigned long) s->inf->st_size);
+      if(s->checksum) {
+	out_print(res,
+		  "  %-33s %s(%s)\n",
+		  "checksum", s->inf->cs_sum, 
+		  checksumnames[s->checksum->type]);
       }
     }
-    if(s->type == TYPE_DEVICE)
-    {
+    if(s->type == TYPE_DEVICE) {
       out_print(res,
-        "  %-33s %ld B\n"
-        "  %-33s %ld [%.1f MB]\n"
-        "  %-33s %ld [%.1f MB] [%.1f%%]\n"
-        "  %-33s %ld [%.1f MB] [%.1f%%]\n",
-        "block size",
-        s->inf->f_bsize,
-        "blocks total",
-        s->inf->f_blocks,
-        (float) s->inf->f_blocks/1048576*s->inf->f_bsize,
-        "blocks free for non superuser",
-        s->inf->f_blocksfree,
-        (float) s->inf->f_blocksfree/1048576*s->inf->f_bsize,
-        (float) 100*s->inf->f_blocksfree/s->inf->f_blocks,
-        "blocks free total",
-        s->inf->f_blocksfreetotal,
-        (float) s->inf->f_blocksfreetotal/1048576*s->inf->f_bsize,
-        (float) 100*s->inf->f_blocksfreetotal/s->inf->f_blocks);
-      if(s->inf->f_files > 0)
-      {
-        out_print(res,
-          "  %-33s %ld\n"
-          "  %-33s %ld [%.1f%%]\n",
-          "inodes total",
-          s->inf->f_files,
-          "inodes free",
-          s->inf->f_filesfree,
-          (float) 100*s->inf->f_filesfree/s->inf->f_files);
+		"  %-33s %ld B\n"
+		"  %-33s %ld [%.1f MB]\n"
+		"  %-33s %ld [%.1f MB] [%.1f%%]\n"
+		"  %-33s %ld [%.1f MB] [%.1f%%]\n",
+		"block size",
+		s->inf->f_bsize,
+		"blocks total",
+		s->inf->f_blocks,
+		((float)s->inf->f_blocks/(float)1048576*
+		 (float)s->inf->f_bsize),
+		"blocks free for non superuser",
+		s->inf->f_blocksfree,
+		((float)s->inf->f_blocksfree/(float)1048576*
+		 (float)s->inf->f_bsize),
+		((float)100*(float)s->inf->f_blocksfree/
+		 (float)s->inf->f_blocks),
+		"blocks free total",
+		s->inf->f_blocksfreetotal,
+		((float)s->inf->f_blocksfreetotal/(float)1048576*
+		 (float)s->inf->f_bsize),
+		((float)100*(float)s->inf->f_blocksfreetotal/
+		 (float)s->inf->f_blocks));
+      if(s->inf->f_files > 0) {
+	out_print(res,
+		  "  %-33s %ld\n"
+		  "  %-33s %ld [%.1f%%]\n",
+		  "inodes total",
+		  s->inf->f_files,
+		  "inodes free",
+		  s->inf->f_filesfree,
+		  ((float)100*(float)s->inf->f_filesfree/
+		   (float)s->inf->f_files));
       }
     }
-    if(s->type == TYPE_PROCESS)
-    {
-      char *uptime= get_uptime(s->inf->uptime, " ");
+    if(s->type == TYPE_PROCESS) {
+      char *uptime= Util_getUptime(s->inf->uptime, " ");
       out_print(res,
-        "  %-33s %d\n"
-        "  %-33s %d\n"
-        "  %-33s %s\n",
-        "pid", s->inf->pid,
-        "parent pid", s->inf->ppid,
-        "uptime", uptime);
+		"  %-33s %d\n"
+		"  %-33s %d\n"
+		"  %-33s %s\n",
+		"pid", s->inf->pid,
+		"parent pid", s->inf->ppid,
+		"uptime", uptime);
       FREE(uptime);
-      if(Run.doprocess)
-      {
-        out_print(res,
-          "  %-33s %d\n"
-          "  %-33s %ld\n"
-          "  %-33s %ld\n"
-          "  %-33s %.1f%%\n"
-          "  %-33s %.1f%%\n"
-          "  %-33s %.1f%%\n"
-          "  %-33s %.1f%%\n",
-          "childrens", s->inf->children,
-          "memory kilobytes", s->inf->mem_kbyte,
-          "memory kilobytes total", s->inf->total_mem_kbyte,
-          "memory percent", s->inf->mem_percent/10.0,
-          "memory percent total", s->inf->total_mem_percent/10.0,
-          "cpu percent", s->inf->cpu_percent/10.0,
-          "cpu percent total", s->inf->total_cpu_percent/10.0);
+      if(Run.doprocess)	{
+	out_print(res,
+		  "  %-33s %d\n"
+		  "  %-33s %ld\n"
+		  "  %-33s %ld\n"
+		  "  %-33s %.1f%%\n"
+		  "  %-33s %.1f%%\n"
+		  "  %-33s %.1f%%\n"
+		  "  %-33s %.1f%%\n",
+		  "childrens", s->inf->children,
+		  "memory kilobytes", s->inf->mem_kbyte,
+		  "memory kilobytes total", s->inf->total_mem_kbyte,
+		  "memory percent", s->inf->mem_percent/10.0,
+		  "memory percent total", s->inf->total_mem_percent/10.0,
+		  "cpu percent", s->inf->cpu_percent/10.0,
+		  "cpu percent total", s->inf->total_cpu_percent/10.0);
       }
     }
-    if(s->type == TYPE_HOST && s->icmplist)
-    {
+    if(s->type == TYPE_HOST && s->icmplist) {
       Icmp_T i;
-      for(i= s->icmplist; i; i= i->next)
-      {
-        out_print(res,
-          "  %-33s %.3fs [%s]\n",
-          "icmp response time", i->is_available?i->response:-1.,
-          icmpnames[i->type]);
+      for(i= s->icmplist; i; i= i->next) {
+	out_print(res,
+		  "  %-33s %.3fs [%s]\n",
+		  "icmp response time", i->is_available?i->response:-1.,
+		  icmpnames[i->type]);
       }
     }
-    if((s->type == TYPE_HOST || s->type == TYPE_PROCESS) && s-> portlist)
-    {
+    if((s->type == TYPE_HOST || s->type == TYPE_PROCESS) && s-> portlist) {
       Port_T p;
-      for(p= s->portlist; p; p= p->next)
-      {
-        if(p->family == AF_INET)
-        {
-          out_print(res,
-            "  %-33s %.3fs to %s:%d%s [%s%s]\n",
-            "port response time", p->is_available?p->response:-1., p->hostname,
-            p->port, p->request?p->request:"", p->protocol->name,
-            p->SSL.use_ssl?" via SSL":"");
-            
-            
-        }
-        else if(p->family == AF_UNIX)
-        {
-          out_print(res,
-            "  %-33s %.3fs to %s:%s\n",
-            "unix socket response time", p->is_available?p->response:-1.,
-            p->pathname, p->protocol->name);
-        }
+      for(p= s->portlist; p; p= p->next) {
+	if(p->family == AF_INET) {
+	  out_print(res,
+		    "  %-33s %.3fs to %s:%d%s [%s%s]\n",
+		    "port response time", p->is_available?p->response:-1., 
+		    p->hostname,
+		    p->port, p->request?p->request:"", p->protocol->name,
+		    p->SSL.use_ssl?" via SSL":"");
+	} else if(p->family == AF_UNIX) {
+	  out_print(res,
+		    "  %-33s %.3fs to %s [%s]\n",
+		    "unix socket response time", p->is_available?p->response:-1.,
+		    p->pathname, p->protocol->name);
+	}
       }
     }
   }
   ctime_r(&s->collected, time);
-  out_print(res,
-    "  %-33s %s\n",
-    "data collected", time);
+  out_print(res, "  %-33s %s\n", "data collected", time);
 }
 
 
@@ -2492,13 +2355,3 @@ static char *get_service_status_text(Service_T s) {
 
 }
 
-
-/* Test whether service status data are available. If not, return 0 */
-static int check_service_status(Service_T s) {
-
-  return( !((s->monitor!=MONITOR_YES)||
-            (s->error&EVENT_NONEXIST)||
-            (s->error&EVENT_DATA) ));
-
-}
-
