@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -34,7 +34,8 @@
 #define DEFAULT_QUEUE_LEN  10
 
 typedef struct host_allow {
-  char *name;  
+  unsigned long network;
+  unsigned long mask;
   /* For internal use */
   struct host_allow *next;
 } *HostsAllow;
@@ -43,6 +44,7 @@ typedef struct host_allow {
 void start_httpd(int port, int backlog, char *bindAddr);
 void stop_httpd();
 int add_host_allow(char *);
+int add_net_allow(char *);
 int has_hosts_allow();
 void destroy_hosts_allow();
 
