@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -101,7 +101,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: processor.c,v 1.45 2004/08/02 20:06:39 martinp Exp $
+ *  @version \$Id: processor.c,v 1.53 2005/02/20 22:39:46 hauk Exp $
  *
  *  @file
  */
@@ -219,21 +219,18 @@ void out_print(HttpResponse res, const char *m, ...) {
     long need= 0;
     ssize_t have= 0;
 
+    ASSERT(res);
+
     va_start(ap, m);
-    buf= format(m, ap, &need);
+    buf= Util_formatString(m, ap, &need);
     va_end(ap);
     have= res->bufsize - res->bufused;
     if(have <= need) {
-      res->outputbuffer=
-	xresize(res->outputbuffer,(res->bufsize + need + RES_STRLEN));
-      res->bufsize+= (need + RES_STRLEN);
-      if(!res->bufused) {
-	memset(res->outputbuffer, 0, res->bufsize);
-      }
+      res->bufsize += need + RES_STRLEN;
+      res->outputbuffer= xresize(res->outputbuffer, res->bufsize);
     }
     memcpy(&res->outputbuffer[res->bufused], buf, need); 
     res->bufused+= need;
-    res->outputbuffer[res->bufused]= 0; 
     FREE(buf);
   }
 }
@@ -250,10 +247,11 @@ void out_print(HttpResponse res, const char *m, ...) {
  * @param value Header key value
  */
 void set_header(HttpResponse res, const char *name, const char *value) {
-  HttpHeader h;
+  HttpHeader h= NULL;
 
   ASSERT(res);
   ASSERT(name);
+
   NEW(h);
   h->name= xstrdup(name);
   h->value= xstrdup(value);
@@ -534,7 +532,7 @@ static void send_response(HttpResponse res) {
  * Returns a new HttpRequest object wrapping the client request
  */
 static HttpRequest create_HttpRequest(Socket_T S) {
-  HttpRequest req;
+  HttpRequest req= NULL;
   char url[REQ_STRLEN];
   char line[REQ_STRLEN];
   char protocol[STRLEN]; 
@@ -544,8 +542,7 @@ static HttpRequest create_HttpRequest(Socket_T S) {
     internal_error(S, SC_BAD_REQUEST, "No request found");
     return NULL;
   }
-  chomp(line,REQ_STRLEN);
-  /* RATS: ignore */ /* chomp does zero termination */
+  Util_chomp(line);
   if(sscanf(line, "%s %s HTTP/%3[1.0]", method, url, protocol) != 3) {
     internal_error(S, SC_BAD_REQUEST, "Cannot parse request");
     return NULL;
@@ -556,7 +553,7 @@ static HttpRequest create_HttpRequest(Socket_T S) {
   }
   NEW(req);
   req->S= S;
-  url_decode(url);
+  Util_urlDecode(url);
   req->url= xstrdup(url);
   req->method= xstrdup(method);
   req->protocol= xstrdup(protocol); 
@@ -575,7 +572,7 @@ static HttpRequest create_HttpRequest(Socket_T S) {
  * the set_XXX methods to change the object.
  */
 static HttpResponse create_HttpResponse(Socket_T S) {
-  HttpResponse res;
+  HttpResponse res= NULL;
 
   NEW(res);
   res->S= S;
@@ -596,7 +593,7 @@ static HttpResponse create_HttpResponse(Socket_T S) {
 static void create_headers(HttpRequest req) {
   Socket_T S;
   char *value;
-  HttpHeader header;
+  HttpHeader header= NULL;
   char line[REQ_STRLEN];
 
   S= req->S;
@@ -608,9 +605,9 @@ static void create_headers(HttpRequest req) {
     if(NULL != (value= strchr(line, ':'))) {
       NEW(header);
       *value++= 0;
-      trim(line);
-      trim(value);
-      chomp(value, (REQ_STRLEN-(value-line)));
+      Util_trim(line);
+      Util_trim(value);
+      Util_chomp(value);
       header->name= xstrdup(line);
       header->value= xstrdup(value);
       header->next= req->headers;
@@ -766,7 +763,7 @@ static int basic_authenticate(HttpRequest req) {
   char uname[STRLEN];
   const char *credentials= get_header(req, "Authorization");
 
-  if(! (credentials && starts_with(credentials, "Basic "))) {
+  if(! (credentials && Util_startsWith(credentials, "Basic "))) {
     return FALSE;
   }
   strncpy(buf, &credentials[6], STRLEN);
@@ -783,13 +780,13 @@ static int basic_authenticate(HttpRequest req) {
     return FALSE;
   }
   /* Check if user exist */
-  if(NULL==get_user_credentials(uname)) {
+  if(NULL==Util_getUserCredentials(uname)) {
     log("Warning: Client '%s' supplied unknown user '%s'"
 	" accessing monit httpd\n", socket_get_remote_host(req->S), uname); 
     return FALSE;
   }
   /* Check if user has supplied the right password */
-  if(! compare_user_credentials(uname,  password)) {
+  if(! Util_checkCredentials(uname,  password)) {
     log("Warning: Client '%s' supplied wrong password for user '%s'"
 	" accessing monit httpd\n", socket_get_remote_host(req->S), uname); 
     return FALSE;
@@ -847,7 +844,7 @@ static HttpParameter parse_parameters(char *query_string) {
     if(token==KEY)
       key= value;
     else if(token==VALUE) {
-      HttpParameter p;
+      HttpParameter p= NULL;
       if(!key) goto error;
       NEW(p);
       p->name= key;
@@ -861,7 +858,9 @@ static HttpParameter parse_parameters(char *query_string) {
 error:
   FREE(key);
   FREE(value);
-  destroy_entry(head);
+  if ( head != NULL ) {
+    destroy_entry(head);
+  }
   return NULL;
 }
 
