@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -80,7 +80,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: log.c,v 1.20 2004/02/13 15:29:11 hauk Exp $
+ *  @version \$Id: log.c,v 1.23 2005/01/06 20:51:49 martinp Exp $
  *
  *  @file
  */
@@ -140,7 +140,7 @@ void log_log(const char *s, ...) {
   ASSERT(s);
   
   va_start(ap,s);
-  msg= format(s, ap, &len);
+  msg= Util_formatString(s, ap, &len);
   va_end(ap);
 
   if(! Run.dolog) goto nolog;
@@ -224,7 +224,7 @@ static char *timestr() {
   
   time(&now);
   if(!strftime(time_str, STRLEN, TIMEFORMAT, localtime_r(&now, &tm))) {
-    memset(time_str, 0, STRLEN);
+    *time_str= 0;
   }
   
   return time_str;
