@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -66,6 +66,8 @@
 #include "process.h"
 #include "md5.h"
 #include "sha.h"
+#include "state.h"
+
 
 /**
  *  DESCRIPTION
@@ -78,7 +80,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: monitor.c,v 1.115 2004/07/13 07:03:19 chopp Exp $
+ *  @version \$Id: monitor.c,v 1.119 2005/02/13 19:01:45 martinp Exp $
  *
  *  @file
  */
@@ -92,7 +94,6 @@ static void  do_reinit();           /* Re-initialize the runtime application */
 static void  do_action(char **);         /* Dispatch to the submitted action */
 static void  do_exit();                                    /* Finalize monit */
 static void  do_default();                              /* Do default action */
-static int   do_wakeupcall();              /* Wakeup a sleeping monit daemon */
 static void  handle_options(int, char **);         /* Handle program options */
 static void  help();                 /* Print program help message to stdout */
 static void  version();                         /* Print version information */
@@ -109,7 +110,7 @@ static RETSIGTYPE do_wakeup(int);  /* Signalhandler for a daemon wakeup call */
  */
 int main(int argc, char **argv) {
 
-  prog= stripfilename(argv[0]);
+  prog= Util_basename(argv[0]);
   init_env();
   handle_options(argc, argv);
  
@@ -117,12 +118,33 @@ int main(int argc, char **argv) {
   do_action(argv); 
   do_exit();
 
-  /* We will exit in do_exit, but according to main's prototype: */
-  exit(0);
+  return 0;
 
 }
 
 
+/**
+ * Wakeup a sleeping monit daemon.
+ * Returns TRUE on success otherwise FALSE
+ */
+int do_wakeupcall() {
+
+  pid_t pid;
+  
+  if((pid= exist_daemon()) > 0) {
+    
+    kill(pid, SIGUSR1);
+    log("%s daemon at %d awakened\n", prog, pid);
+    
+    return TRUE;
+    
+  }
+  
+  return FALSE;
+  
+}
+
+
 /* ----------------------------------------------------------------- Private */
 
 
@@ -185,7 +207,7 @@ static void do_init() {
    */
   if(! Run.controlfile) {
     
-    Run.controlfile= find_rcfile();
+    Run.controlfile= File_findControlFile();
     
   }
   
@@ -239,15 +261,15 @@ static void do_init() {
   /* 
    * Initialize Runtime file variables 
    */
-  init_files();
+  File_init();
 
   /* 
    * Should we print debug information ? 
    */
   if(Run.debug) {
     
-    printrunlist();
-    printservicelist();
+    Util_printRunList();
+    Util_printServiceList();
     
   }
 
@@ -295,15 +317,15 @@ static void do_reinit() {
   }
   
   /* Reinitialize Runtime file variables */
-  init_files();
+  File_init();
 
-  if(! create_pidfile(Run.pidfile)) {
+  if(! File_createPidFile(Run.pidfile)) {
     log("%s daemon died\n", prog);
     exit(1);
   }
 
   /* Update service data from the state repository */
-  state_update();
+  State_update();
   
   /* Start http interface */
   if(can_http())
@@ -373,28 +395,6 @@ static void do_action(char **args) {
 }
 
 
-/**
- * Wakeup a sleeping monit daemon.
- * Returns TRUE on success otherwise FALSE
- */
-static int do_wakeupcall() {
-
-  pid_t pid;
-  
-  if((pid= exist_daemon()) > 0) {
-    
-    kill(pid, SIGUSR1);
-    log("%s daemon at %d awakened\n", prog, pid);
-    
-    return TRUE;
-    
-  }
-  
-  return FALSE;
-  
-}
-
-
 /**
  * Finalize monit
  */
@@ -449,15 +449,15 @@ static void do_default() {
     if(Run.init != TRUE)
       daemonize(); 
     
-    if(! create_pidfile(Run.pidfile)) {
+    if(! File_createPidFile(Run.pidfile)) {
       log("%s daemon died\n", prog);
       exit(1);
     }
 
-    if(state_should_update())
-      state_update();
+    if(State_shouldUpdate())
+      State_update();
 
-    atexit(finalize_files);
+    atexit(File_finalize);
   
     if(can_http())
       monit_http(START_HTTP);
@@ -465,7 +465,7 @@ static void do_default() {
     for(;;) {
 
       validate();
-      state_save();
+      State_save();
       sleep(Run.polltime);
 
       if(Run.doreload)
@@ -549,9 +549,9 @@ static void handle_options(int argc, char **argv) {
 
     case 'H':
         if (argc > optind) {
-          printhash(argv[optind]);
+          Util_printHash(argv[optind]);
         } else {
-          printhash(NULL);
+          Util_printHash(NULL);
         }
           
         exit(0);
@@ -639,7 +639,7 @@ static void help() {
 static void version() {
   
   printf("This is monit version %s\n", VERSION);
-  printf("Copyright (C) 2000-2004 by the monit project group.");
+  printf("Copyright (C) 2000-2005 by the monit project group.");
   printf(" All Rights Reserved.\n");
  
 }
