@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -55,6 +55,10 @@
 #include <regex.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #include "ssl.h"
 #include "socket.h"
 
@@ -65,6 +69,7 @@
 #define STRERROR            strerror(errno)
 #define STRLEN             256
 #define ARGMAX             64
+#define HTTP_CONTENT_MAX   (1024*10)
 /* Set log file mode: "-rw-rw-r--" */
 #define LOGMASK            0112
 /* Set pid file mode: "-rw-r--r--" */
@@ -74,7 +79,10 @@
 #define MYSTATEFILE        "monit.state"
 
 #define LOCALHOST          "localhost"
-#define SMTP_PORT          25
+
+#define PORT_SMTP          25
+#define PORT_HTTP          80
+#define PORT_HTTPS         443
 
 #define SSL_TIMEOUT        15
 
@@ -142,6 +150,10 @@
 #define HASH_SHA1          2
 #define DEFAULT_HASH       HASH_MD5
 
+#define PROTOCOL_NULL      0
+#define PROTOCOL_HTTP      1
+#define PROTOCOL_HTTPS     2
+
 /** ------------------------------------------------- Special purpose macros */
 
 
@@ -225,6 +237,43 @@ typedef struct myeventaction {
 } *EventAction_T;
 
 
+/** Defines an url object */
+typedef struct myurl {
+  char *url;                                                  /**< Full URL */
+  char *protocol;                                    /**< URL protocol type */
+  char *user;                                        /**< URL user     part */
+  char *password;                                    /**< URL password part */
+  char *hostname;                                    /**< URL hostname part */
+  int   port;                                        /**< URL port     part */
+  char *path;                                        /**< URL path     part */
+  char *query;                                       /**< URL query    part */
+} *URL_T;
+
+
+/** Defines a HTTP client request object */
+typedef struct myrequest {
+  URL_T url;                                               /**< URL request */
+  int   operator;                 /**< Response content comparison operator */
+#ifdef HAVE_REGEX_H
+  regex_t *regex;                   /* regex used to test the response body */
+#else
+  char *regex;                 /* string to search for in the response body */
+#endif
+} *Request_T;
+
+
+/** Defines an event notification and status receiver object */
+typedef struct mycollector {
+  URL_T url;                                             /**< URL definition */
+  Ssl_T ssl;                                             /**< SSL definition */
+  int   timeout;              /**< The timeout to wait for connection or i/o */
+  Socket_T       socket;                     /**< Socket used for connection */
+
+  /** For internal use */
+  struct mycollector *next;                      /**< next receiver in chain */
+} *Collector_T;
+
+
 /** Defines a mailinglist object */
 typedef struct mymail {
   char *to;                         /**< Mail address for alert notification */
@@ -314,7 +363,6 @@ struct myrun {
   char *httpsslpem;                       /**< PEM file for the HTTPS server */
   int  clientssl;   /**< TRUE if monit HTTP server uses ssl with client auth */
   char *httpsslclientpem;      /**< PEM file/dir to check against at connect */
-  int  servicessl;                 /**< TRUE if monit has ssl service checks */
   int  allowselfcert;   /**< TRUE if self certified client certs are allowed */
   int  httpdsig;   /**< TRUE if monit HTTP server presents version signature */
   int  httpdport;                    /**< The monit http server's portnumber */
@@ -327,6 +375,7 @@ struct myrun {
   mode_t umask;                /**< The initial umask monit was started with */
   int  testing;   /**< Running in configuration testing mode - TRUE or FALSE */
   int  wait_start;         /**< Number of threads waiting for process' start */
+  time_t incarnation;              /**< Unique ID for running monit instance */
 
        /** An object holding program relevant "environment" data, see; env.c */
   struct myenvironment {
@@ -338,6 +387,7 @@ struct myrun {
   int mailserver_timeout;    /**< Connect and read timeout for a SMTP server */
   Mail_T maillist;                /**< Global alert notification mailinglist */
   MailServer_T mailservers;    /**< List of MTAs used for alert notification */
+  Collector_T collectors;  /**< Event notification and status receivers list */
   Auth_T credentials;    /** A list holding Basic Authentication information */
                                       /** User selected standard mail format */
   struct myformat {
@@ -370,7 +420,6 @@ typedef struct mygenericproto {
   struct mygenericproto *next;
 } *Generic_T;
 
-
 /** Defines a port object */
 typedef struct myport {
   volatile int socket;                       /**< Socket used for connection */
@@ -388,15 +437,33 @@ typedef struct myport {
   int is_available;                /**< TRUE if the server/port is available */
   double response;                      /**< Socket connection response time */
   EventAction_T action;  /**< Description of the action upon event occurence */
+  /** Apache-status specific parameters */
+  struct apache_status {
+    int loglimit;                  /**< Max percentatge of logging processes */
+    int loglimitOP;                                   /**< loglimit operator */
+    int closelimit;             /**< Max percentatge of closinging processes */
+    int closelimitOP;                               /**< closelimit operator */
+    int dnslimit;         /**< Max percentatge of processes doing DNS lookup */
+    int dnslimitOP;                                   /**< dnslimit operator */
+    int keepalivelimit;          /**< Max percentatge of keepalive processes */
+    int keepalivelimitOP;                       /**< keepalivelimit operator */
+    int replylimit;               /**< Max percentatge of replying processes */
+    int replylimitOP;                               /**< replylimit operator */
+    int requestlimit;     /**< Max percentatge of processes reading requests */
+    int requestlimitOP;                           /**< requestlimit operator */
+    int startlimit;            /**< Max percentatge of processes starting up */
+    int startlimitOP;                               /**< startlimit operator */
+    int waitlimit;  /**< Min percentatge of processes waiting for connection */
+    int waitlimitOP;                                 /**< waitlimit operator */
+    int gracefullimit;/**< Max percentatge of processes gracefully finishing */
+    int gracefullimitOP;                         /**< gracefullimit operator */
+    int cleanuplimit;      /**< Max percentatge of processes in idle cleanup */
+    int cleanuplimitOP;                           /**< cleanuplimit operator */
+  } ApacheStatus;
   
-  struct {
-    int use_ssl;          /**< TRUE if this port requires SSL for connection */
-    int version;                  /**< The SSL version to use for connection */
-    char *certmd5;     /**< The expected md5 sum of the server's certificate */
-  } SSL;
-
-  /**< Object used for testing a port's service */
-  Protocol_T protocol;
+  Ssl_T SSL;                                             /**< SSL definition */
+  Protocol_T protocol;     /**< Protocol object for testing a port's service */
+  Request_T url_request;             /**< Optional url client request object */
   
   /** For internal use */
   struct myport *next;                               /**< next port in chain */
@@ -524,14 +591,20 @@ typedef struct myinfo {
   long   f_files;                        /**< Total file nodes in filesystem */
   long   f_filesfree;                     /**< Free file nodes in filesystem */
   char   mntpath[STRLEN];      /**< Filesystem file, directory or mountpoint */
+  int    inode_percent;                      /**< Used inode percentage * 10 */
+  long   inode_total;                          /**< Used inode total objects */
+  int    space_percent;                      /**< Used space percentage * 10 */
+  long   space_total;                           /**< Used space total blocks */
 
-  /* FIle specific */
-  size_t st_size;                                                 /**< Size */
-  char  *cs_sum;                                              /**< Checksum */
+  /* File specific */
+  size_t st_size;                                                  /**< Size */
+  char  *cs_sum;                                               /**< Checksum */
 
   /* Process specific */
-  int    pid;
-  int    ppid;
+  int    _pid;                              /**< Process PID from last cycle */
+  int    _ppid;                      /**< Process parent PID from last cycle */
+  int    pid;                             /**< Process PID from actual cycle */
+  int    ppid;                     /**< Process parent PID from actual cycle */
   int    status_flag;
   int    children;
   long   mem_kbyte;    
@@ -577,12 +650,15 @@ typedef struct myservice {
   Gid_T       gid;                                            /**< Gid check */
   Icmp_T      icmplist;                                 /**< ICMP check list */
   Perm_T      perm;                                    /**< Permission check */
-  Port_T      portlist;              /**< Portnumbers the service listens on */
+  Port_T      portlist; /**< Portnumbers to check, either local or at a host */
   Resource_T  resourcelist;                          /**< Resouce check list */
   Size_T      sizelist;                                 /**< Size check list */
   Timestamp_T timestamplist;                       /**< Timestamp check list */
   Uid_T       uid;                                            /**< Uid check */
   
+  EventAction_T action_PID;   /**< Description of the action upon pid change */
+  EventAction_T action_PPID; /**< Description of the action upon ppid change */
+
   /** General event handlers */
   EventAction_T action_DATA;       /**< Description of the action upon event */
   EventAction_T action_EXEC;       /**< Description of the action upon event */
@@ -599,6 +675,7 @@ typedef struct myservice {
   /** Events */
   struct myevent {
     int               id;                      /**< The event identification */
+    time_t            collected;                 /**< When the event occured */
     struct myservice *source;                              /**< Event source */
     short             state;            /**< TRUE if failed, FALSE if passed */
     short             state_changed;              /**< TRUE if state changed */
@@ -625,7 +702,6 @@ typedef struct myevent *Event_T;
 
 /* -------------------------------------------------------- Global variables */
 
-
 char   *prog;                                  /**< The Name of this Program */
 struct myrun Run;                      /**< Struct holding runtime constants */
 Service_T servicelist;                /**< The service list (created in p.y) */
@@ -639,38 +715,11 @@ extern int            oldptreesize;
 
 /* ------------------------------------------------------- Public prototypes */
 
+#include "util.h"
+#include "file.h"
+
+/* FIXME: move remaining prototypes into seperate header-files */
 
-char *trim(char *);
-char *ltrim(char *);
-char *rtrim(char *);
-void  trim_quotes(char *);
-char *replace_char(char *, char, char);
-char *replace_string(char **, const char *, const char *);
-int   count_words(char *, const char *);
-int   starts_with(const char *, const char *);
-void  handle_string_escapes(char *);
-void  chomp(char *,int);
-int   exist_service(const char *);
-int   get_service_list_length();
-Service_T get_service(const char *);
-void  printrunlist();
-void  printservice(Service_T);
-void  printservicelist();
-pid_t get_pid(char *);
-int   is_process_running(Service_T);
-int   is_strdefined(char *);
-int   isreg_file(char *);
-char *stripfilename(char*);
-int   exist_file(char *);
-char *get_RFC822date(long *);
-char *get_uptime(time_t, char *);
-time_t get_process_uptime(char *);
-char *get_checksum(char *, int);
-char *url_encode(char *);
-char *url_decode(char *);
-char *get_basic_authentication_header();
-Auth_T get_user_credentials(char *);
-int   compare_user_credentials(char *, char *);
 int   parse(char *);
 void  control_service(const char *, const char *);
 void  control_service_daemon(const char *, const char *);
@@ -684,12 +733,7 @@ void  log_close();
 void  validate() ;
 void  daemonize() ;
 void  gc();
-void  gc_mail_list(Mail_T*);
-void  init_files();
-time_t get_timestamp(char *, mode_t);
-void  finalize_files();
-char *find_rcfile();    
-int   create_pidfile(char *);
+void  gc_mail_list(Mail_T *);
 int   kill_daemon(int);
 int   exist_daemon(); 
 void  sendmail(Mail_T);
@@ -706,10 +750,6 @@ char *format(const char *, va_list, long *);
 void  redirect_stdfd();
 void  fd_close();
 pid_t getpgid(pid_t);
-int   check_file_stat(char *, char *, int);
-void  state_save();
-int   state_should_update();
-void  state_update();
 #if ! HAVE_MALLOC
 void *rpl_malloc (size_t __size);
 #endif
@@ -720,8 +760,13 @@ int  check_device(Service_T);
 int  check_file(Service_T);
 int  check_directory(Service_T);
 int  check_remote_host(Service_T);
+int  check_URL(Service_T s);
 int  sha_md5_stream (FILE *, void *, void *);
 void reset_procinfo(Service_T);
+int  check_service_status(Service_T);
 void printhash(char *);  
+char *status_xml(Event_T);
+void handle_collector(Event_T);
+int  do_wakeupcall();
 
 #endif
