@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -61,7 +61,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: process.c,v 1.12 2004/09/10 19:34:54 martinp Exp $
+ *  @version \$Id: process.c,v 1.22 2005/02/15 19:42:00 martinp Exp $
  *
  *  @file
  */
@@ -89,6 +89,7 @@ char icmpnames[][STRLEN]=     {"Echo Reply", "", "", "Destination Unreachable",
                                "Timestamp Reply", "Information Request",
                                "Information Reply", "Address Mask Request",
                                "Address Mask Reply"};
+char sslnames[][STRLEN]=      {"auto", "v2", "v3", "tls"};
 
 int   include_children= TRUE;
 int   num_cpus=1;
@@ -123,11 +124,15 @@ int update_process_data(Service_T s, ProcessTree_T *pt, int treesize,
   ASSERT(s);
   ASSERT(systeminfo.mem_kbyte_max > 0);
 
-  s->inf->pid=pid;
+  /* save the previous pid and set actual one */
+  s->inf->_pid= s->inf->pid;
+  s->inf->pid = pid;
 
   if ((leaf = findprocess(pid, pt, treesize)) != NULL ) {
  
-    s->inf->ppid=leaf->ppid;
+    /* save the previous ppid and set actual one */
+    s->inf->_ppid= s->inf->ppid;
+    s->inf->ppid= leaf->ppid;
     s->inf->children=leaf->children_sum;
     s->inf->mem_kbyte=leaf->mem_kbyte;
     s->inf->status_flag=leaf->status_flag;
@@ -183,44 +188,40 @@ int update_process_data(Service_T s, ProcessTree_T *pt, int treesize,
  */
 int update_system_load(ProcessTree_T *pt, int treesize) {
 
-  ASSERT(systeminfo.mem_kbyte_max > 0);
-
-  /** Get load average triplet */
-  if(-1 == getloadavg_sysdep(systeminfo.loadavg, 3))
-  {
-    log("'system' statistic error -- load average gathering failed\n");
-    return FALSE;
-  }
-  DEBUG("'system' load average [%.2f][%.2f][%.2f]\n",
-    systeminfo.loadavg[0],
-    systeminfo.loadavg[1],
-    systeminfo.loadavg[2]);
-
   if(Run.doprocess)
   {
     ProcessTree_T *leaf;
   
+    ASSERT(systeminfo.mem_kbyte_max > 0);
+
+    /** Get load average triplet */
+    if(-1 == getloadavg_sysdep(systeminfo.loadavg, 3))
+    {
+      log("'system' statistic error -- load average gathering failed\n");
+      goto error1;
+    }
+    DEBUG("'system' load average [%.2f][%.2f][%.2f]\n",
+      systeminfo.loadavg[0],
+      systeminfo.loadavg[1],
+      systeminfo.loadavg[2]);
+
     /** Get real memory usage statistic */
     if(!used_system_memory_sysdep(&systeminfo))
     {
       DEBUG("'system' statistic -- memory usage gathering method fallback\n");
       /* Update the total real memory usage by monitoring process with PID 1 */
-      if((leaf = findprocess(1, pt, treesize)))
+      if((leaf = findprocess(1, pt, treesize)) && leaf->mem_kbyte_sum > 0)
       {
         systeminfo.total_mem_kbyte = leaf->mem_kbyte_sum;
       }
       else
       {
         log("'system' statistic error -- memory usage gathering failed\n");
-        return FALSE;
+        goto error2;
       }
     }
-    else
-    {
-      systeminfo.total_mem_percent = (int)(
-        1000 * (double)systeminfo.total_mem_kbyte / systeminfo.mem_kbyte_max
-      );
-    }
+    systeminfo.total_mem_percent = (int)(1000 *
+      (double)systeminfo.total_mem_kbyte / (double)systeminfo.mem_kbyte_max);
     DEBUG("'system' memory usage %.1f%% [%ld kB]\n",
       systeminfo.total_mem_percent / 10.,
       systeminfo.total_mem_kbyte);
@@ -239,104 +240,137 @@ int update_system_load(ProcessTree_T *pt, int treesize) {
       else
       {
         log("'system' statistic error -- cpu usage gathering failed\n");
-        return FALSE;
+        goto error3;
       }
     }
     DEBUG("'system' cpu usage %.1f%%us %.1f%%sy %.1f%%wa\n",
       systeminfo.total_cpu_user_percent / 10.,
       systeminfo.total_cpu_syst_percent / 10.,
       systeminfo.total_cpu_wait_percent / 10.);
+
+    return TRUE;
   }
-  return TRUE;
+
+  error1:
+  systeminfo.loadavg[0] = 0;
+  systeminfo.loadavg[1] = 0;
+  systeminfo.loadavg[2] = 0;
+  error2:
+  systeminfo.total_mem_kbyte = 0;
+  systeminfo.total_mem_percent = 0;
+  error3:
+  systeminfo.total_cpu_user_percent = 0;
+  systeminfo.total_cpu_syst_percent = 0;  
+  systeminfo.total_cpu_wait_percent = 0;  
+  return FALSE;
 }
 
 
 /**
- * Initilize the process tree 
+ * Initialize the process tree 
  * @return treesize>=0 if succeeded otherwise <0.
  */
-int initprocesstree(ProcessTree_T ** pt_r, int * size_r,
-                    ProcessTree_T ** oldpt_r, int * oldsize_r) {
+int initprocesstree(ProcessTree_T **pt_r,     int *size_r,
+                    ProcessTree_T **oldpt_r, int *oldsize_r) {
   
   int i;
-  ProcessTree_T * oldentry;
-  ProcessTree_T * pt;
-  ProcessTree_T * oldpt;
+  ProcessTree_T *oldentry;
+  ProcessTree_T *pt;
+  ProcessTree_T *oldpt;
+  ProcessTree_T *root;
 
-  if(*pt_r!=NULL) {
-    
-    *oldpt_r=*pt_r; 
-    *oldsize_r=*size_r;
-    
+  if(*pt_r != NULL)
+  {  
+    *oldpt_r   = *pt_r; 
+    *oldsize_r = *size_r; 
   }
   
   if((*size_r = initprocesstree_sysdep(pt_r)) <= 0)
+  {
+    DEBUG("system statistic error -- cannot initialize the process tree\n");
+    return -1;
+  }
+
+  pt    = *pt_r;
+  oldpt = *oldpt_r;
+
+  if ( pt == NULL ) {
     return 0;
+  }
 
-  pt=*pt_r;
-  oldpt=*oldpt_r;
-
-  for( i = 0; i < *size_r; i ++ ) {
-
-    
-    if((oldpt != NULL) &&
-       (NULL != (oldentry= (ProcessTree_T *)findprocess(pt[i].pid,
-                                                        oldpt,
-                                                        *oldsize_r)))) {
-      pt[i].cputime_prev= oldentry->cputime;
-      pt[i].time_prev= oldentry->time;
+  for(i = 0; i < *size_r; i ++)
+  {
+    if(oldpt && (oldentry= findprocess(pt[i].pid, oldpt, *oldsize_r)))
+    {
+      pt[i].cputime_prev = oldentry->cputime;
+      pt[i].time_prev    = oldentry->time;
  
-      if (pt[i].cputime_prev != 0 &&
-          pt[i].cputime != 0 &&
-          pt[i].cputime > pt[i].cputime_prev) {
-        
-        pt[i].cpu_percent=(int)((1000*(double)(pt[i].cputime -
-                                               pt[i].cputime_prev)/
-                                 (pt[i].time - pt[i].time_prev)) / num_cpus);
+      if(pt[i].cputime_prev != 0 &&
+         pt[i].cputime      != 0 &&
+         pt[i].cputime      > pt[i].cputime_prev)
+      {
+        pt[i].cpu_percent = (int)(
+          (
+            1000 *
+            (double)(pt[i].cputime - pt[i].cputime_prev) /
+            (pt[i].time - pt[i].time_prev)
+          ) / num_cpus
+        );
 
-        if ( pt[i].cpu_percent > 1000/num_cpus ) {
-          
+        if(pt[i].cpu_percent > 1000 / num_cpus)
+        {
           /* Just for paranoia! */
-          pt[i].cpu_percent = 1000/num_cpus;
-          
+          pt[i].cpu_percent = 1000 / num_cpus;
         }
-
-      } else {
-
-        pt[i].cpu_percent= 0;
-
       }
-          
-      
-    } else {
-      
-      pt[i].cputime_prev= 0;
-      pt[i].time_prev= 0.0;
-      pt[i].cpu_percent= 0;
-      
+      else
+      {
+        pt[i].cpu_percent = 0;
+      }
+    }
+    else
+    {
+      pt[i].cputime_prev = 0;
+      pt[i].time_prev    = 0.0;
+      pt[i].cpu_percent  = 0;
     }
         
-    if( pt[i].ppid == 0 )
+    if(pt[i].ppid == 0)
+    {
       continue;
+    }
 
-    if(NULL == (pt[i].parent=
-      (ProcessTree_T *)findprocess(pt[i].ppid, pt, *size_r))) {
-      /* inconsitency found, most probably a race condition
-	 we might lack accuracy but we remain stable! */
-      pt[i].pid=0;
+    if(NULL == (pt[i].parent= findprocess(pt[i].ppid, pt, *size_r)))
+    {
+      /* Inconsitency found, process orphaned most probably by a race
+         condition. we might lack accuracy but we remain stable! */
+      DEBUG("system statistic error -- orphaned process id %d\n", pt[i].pid);
+      pt[i].pid = 0;
       continue;
     }
     
-    if(! connectchild((ProcessTree_T *) pt[i].parent, &pt[i])) {
+    if(! connectchild(pt[i].parent, &pt[i]))
+    {
       /* connection to parent process has failed, this is
 	 usually caused in the part above */
+      DEBUG(
+        "system statistic error -- "
+        "cannot connect process id %d to its parent %d\n",
+        pt[i].pid, pt[i].ppid);
       pt[i].pid=0;
       continue;
     }
 
   }
 
-  fillprocesstree((ProcessTree_T *) findprocess(1, pt, *size_r));
+  if(! (root = findprocess(1, pt, *size_r)))
+  {
+    DEBUG("system statistic error -- cannot find process id 1\n",
+      pt[i].pid, pt[i].ppid);
+    return -1;
+  }
+
+  fillprocesstree(root);
 
   return *size_r;
 }
