@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -24,6 +24,10 @@
 #include <stdio.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -94,7 +98,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: sysdep_AIX.c,v 1.11 2004/09/09 20:17:42 martinp Exp $
+ *  @version \$Id: sysdep_AIX.c,v 1.14 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  * most of the code is based on monitor-2.1.5 available on various sources
@@ -181,7 +185,7 @@ int getloadavg_sysdep (double *loadv, int nelem) {
 
 
 /**
- * Read all processes of the proc files system to initilize
+ * Read all processes of the proc files system to initialize
  * the process tree (sysdep version... but should work for
  * all procfs based unices) 
  * @param reference  reference of ProcessTree
