@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -20,6 +20,10 @@
 
 #include <config.h>
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -40,6 +44,14 @@
 #include <kvm.h>
 #endif
 
+#ifdef HAVE_MACH_HOST_INFO_H
+#include <mach/host_info.h>
+#endif
+
+#ifdef HAVE_MACH_MACH_HOST_H
+#include <mach/mach_host.h>
+#endif
+
 #include "monitor.h"
 #include "process.h"
 #include "process_sysdep.h"
@@ -52,7 +64,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_DARWIN.c,v 1.18 2004/09/10 23:20:49 martinp Exp $
+ *  @version \$Id: sysdep_DARWIN.c,v 1.22 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -195,18 +207,27 @@ int getloadavg_sysdep (double *loadv, int nelem) {
  * @return: TRUE if successful, FALSE if failed (or not available)
  */
 int used_system_memory_sysdep(SystemInfo_T *si) {
-  int            mib[] = {CTL_VM, VM_METER};
-  size_t         len   = sizeof(struct vmtotal);
-  struct vmtotal vm;
+  kern_return_t          kret;
+  vm_statistics_data_t   page_info;
+  mach_msg_type_number_t count;
 
-  if(sysctl(mib, 2, &vm, &len, NULL, 0) == -1)
+  count = HOST_VM_INFO_COUNT;
+  kret  = host_statistics(
+            mach_host_self(), HOST_VM_INFO, (host_info_t)&page_info, &count
+          );
+  if(kret == KERN_SUCCESS)
   {
-    log("system statistic error -- cannot get real memory usage: %s\n", STRERROR);
-    return FALSE;
-  }
+    unsigned int pw, pa, pi;
 
-  si->total_mem_kbyte = (unsigned long)(vm.t_arm * pagesize_kbyte);
-  return TRUE;
+    pw = page_info.wire_count * pagesize_kbyte;
+    pa = page_info.active_count * pagesize_kbyte;
+    pi = page_info.inactive_count * pagesize_kbyte;
+
+    si->total_mem_kbyte = pw+pa+pi;
+
+    return TRUE;
+  }
+  return FALSE;
 }
 
 
@@ -215,44 +236,38 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
  * @return: TRUE if successful, FALSE if failed
  */
 int used_system_cpu_sysdep(SystemInfo_T *si) {
-  int    i;
-  int    mib[2];
-  long   cp_time[CPU_STATE_MAX];
-  long   total_new = 0;
-  long   total;
-  size_t len;
+  int                       i;
+  long                      total;
+  long                      total_new = 0;
+  kern_return_t             kret;
+  host_cpu_load_info_data_t cpu_info;
+  mach_msg_type_number_t    count;
 
-  len = sizeof(mib);
-  if(sysctlnametomib("kern.cp_time", mib, &len) == -1)
+  count = HOST_CPU_LOAD_INFO_COUNT;
+  kret  = host_statistics(
+            mach_host_self(), HOST_CPU_LOAD_INFO, (host_info_t)&cpu_info, &count
+          );
+  if(kret == KERN_SUCCESS)
   {
-    log("system statistic error -- cannot get cpu time handler: %s\n", STRERROR);
-    return FALSE;
+    for(i = 0; i < CPU_STATE_MAX; i++)
+    {
+      total_new += cpu_info.cpu_ticks[i];
+    }
+    total     = total_new - total_old;
+    total_old = total_new;
+
+    si->total_cpu_user_percent =
+      (total > 0)?(int)(1000 * (double)(cpu_info.cpu_ticks[CPU_STATE_USER] - cpu_user_old) / total):0;
+    si->total_cpu_syst_percent =
+      (total > 0)?(int)(1000 * (double)(cpu_info.cpu_ticks[CPU_STATE_SYSTEM] - cpu_syst_old) / total):0;
+    si->total_cpu_wait_percent =
+      0; /* there is no wait statistic available */
+
+    cpu_user_old = cpu_info.cpu_ticks[CPU_STATE_USER];
+    cpu_syst_old = cpu_info.cpu_ticks[CPU_STATE_SYSTEM];
+
+    return TRUE;
   }
-
-  len = sizeof(cp_time);
-  if(sysctl(mib, 2, &cp_time, &len, NULL, 0) == -1)
-  {
-    log("system statistic error -- cannot get cpu time: %s\n", STRERROR);
-    return FALSE;
-  }
-
-  for(i = 0; i < CPU_STATE_MAX; i++)
-  {
-    total_new += cp_time[i];
-  }
-  total     = total_new - total_old;
-  total_old = total_new;
-
-  si->total_cpu_user_percent =
-    (total > 0)?(int)(1000 * (double)(cp_time[CPU_STATE_USER] - cpu_user_old) / total):0;
-  si->total_cpu_syst_percent =
-    (total > 0)?(int)(1000 * (double)(cp_time[CPU_STATE_SYSTEM] - cpu_syst_old) / total):0;
-  si->total_cpu_wait_percent =
-    0; /* there is no wait statistic available */
-
-  cpu_user_old = cp_time[CPU_STATE_USER];
-  cpu_syst_old = cp_time[CPU_STATE_SYSTEM];
-
-  return TRUE;
+  return FALSE;
 }
 
