@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -20,6 +20,10 @@
 
 #include <config.h>
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -68,7 +72,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala<martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_FREEBSD.c,v 1.26 2004/09/10 23:17:31 martinp Exp $
+ *  @version \$Id: sysdep_FREEBSD.c,v 1.28 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
