@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -24,6 +24,10 @@
 #include <stdio.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -82,7 +86,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Arkadiusz Miskiewicz <arekm@pld-linux.org>
  *
- *  @version \$Id: sysdep_LINUX.c,v 1.21 2004/09/11 19:07:35 martinp Exp $
+ *  @version \$Id: sysdep_LINUX.c,v 1.28 2005/01/26 00:52:11 rory Exp $
  *
  *  @file
  */
@@ -137,31 +141,26 @@ int init_process_info_sysdep(void) {
 
 
 /**
- * Read all processes of the proc files system to initilize
+ * Read all processes of the proc files system to initialize
  * the process tree (sysdep version... but should work for
  * all procfs based unices) 
  * @param reference  reference of ProcessTree
  * @return treesize>0 if succeeded otherwise =0.
  */
 int initprocesstree_sysdep(ProcessTree_T ** reference) {
-  int            i;
-  int            treesize;
-  int            stat_ppid;
-  char          *tmp;
+  int            i = 0;
+  int            treesize = 0;
+  int            stat_ppid = 0;
+  char          *tmp = NULL;
   char           buf[4096];
   char           stat_item_state;
-  long           stat_item_cutime;
-  long           stat_item_cstime;
-  long           stat_item_rss;
+  long           stat_item_cutime = 0;
+  long           stat_item_cstime = 0;
+  long           stat_item_rss = 0;
   glob_t         globbuf;
-  unsigned long  stat_item_utime;
-  unsigned long  stat_item_stime;
-  ProcessTree_T *pt;
-#ifndef USE_QUICK_MEM_CALC
-  int            statm_item_share;
-  int            statm_item_trs;
-  int            statm_item_drs;
-#endif
+  unsigned long  stat_item_utime = 0;
+  unsigned long  stat_item_stime = 0;
+  ProcessTree_T *pt = NULL;
 
   ASSERT(reference);
 
@@ -183,27 +182,45 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
     
     if(!read_proc_file(buf, 4096, "stat", pt[i].pid))
     {
+      DEBUG(
+        "system statistic error -- cannot read /proc/%d/stat\n",
+        pt[i].pid);
       continue;
     }
 
     pt[i].time = get_float_time();
 
     /* Move along the buffer to get past the process name */
-    if(!(tmp = strrchr(buf, ')') + 2))
+    if(!(tmp = strrchr(buf, ')')))
     {
-      log("system statistic error -- file /proc/%d parse error\n", pt[i].pid);
+      DEBUG(
+        "system statistic error -- file /proc/%d/stat parse error\n",
+        pt[i].pid);
       continue;
     }
 
+    tmp += 2;
+
     /* This implementation is done by using fs/procfs/array.c as a basis
      * it is also worth looking into the source of the procps utils */
-    sscanf(tmp,"%c %d %*d %*d %*d %*d %*u %*u"
-           "%*u %*u %*u %lu %lu %ld %ld %*d %*d %*d "
-           "%*d %*u %*u %ld %*u %*u %*u %*u %*u "
-           "%*u %*u %*u %*u %*u %*u %*u %*u %*d %*d\n",
-           &stat_item_state, &stat_ppid,
-           &stat_item_utime, &stat_item_stime,
-           &stat_item_cutime, &stat_item_cstime, &stat_item_rss);
+    if(sscanf(tmp,
+         "%c %d %*d %*d %*d %*d %*u %*u"
+         "%*u %*u %*u %lu %lu %ld %ld %*d %*d %*d "
+         "%*d %*u %*u %ld %*u %*u %*u %*u %*u "
+         "%*u %*u %*u %*u %*u %*u %*u %*u %*d %*d\n",
+         &stat_item_state,
+         &stat_ppid,
+         &stat_item_utime,
+         &stat_item_stime,
+         &stat_item_cutime,
+         &stat_item_cstime,
+         &stat_item_rss) != 7)
+    {
+      DEBUG(
+        "system statistic error -- file /proc/%d/stat parse error\n",
+        pt[i].pid);
+      continue;
+    }
     
     /* abs to please the compiler... we dont want to shift negatively.
      * why doesn't C understand this??? */
@@ -221,7 +238,6 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
       pt[i].status_flag |= PROCESS_ZOMBIE;
     }
 
-#ifdef USE_QUICK_MEM_CALC
     if(PAGE_TO_KBYTE_SHIFT < 0)
     {
       pt[i].mem_kbyte = (stat_item_rss >> abs(PAGE_TO_KBYTE_SHIFT));
@@ -230,36 +246,6 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
     {
       pt[i].mem_kbyte = (stat_item_rss << abs(PAGE_TO_KBYTE_SHIFT));
     }
-#else
-    if(!read_proc_file(buf, 4096, "statm", pt[i].pid))
-    {
-      pt[i].mem_kbyte = 0;
-    }
-    else
-    {
-      /* This implementation is done by using fs/procfs/array.c as a basis
-       * it is also worth looking into the source of the procps utils.
-       * Beware then proc man page has a wrong sorting of the entries!  */
-      sscanf(buf,"%*d %*d %d %d %*d %d %*d\n",
-             &statm_item_share,&statm_item_trs, &statm_item_drs);
-      
-      if(PAGE_TO_KBYTE_SHIFT < 0)
-      {
-        pt[i].mem_kbyte =
-            (statm_item_trs   >> abs(PAGE_TO_KBYTE_SHIFT)) +
-            (statm_item_drs   >> abs(PAGE_TO_KBYTE_SHIFT)) -
-            (statm_item_share >> abs(PAGE_TO_KBYTE_SHIFT));
-        
-      }
-      else
-      {
-        pt[i].mem_kbyte =
-            (statm_item_trs   << abs(PAGE_TO_KBYTE_SHIFT)) +
-            (statm_item_drs   << abs(PAGE_TO_KBYTE_SHIFT)) -
-            (statm_item_share << abs(PAGE_TO_KBYTE_SHIFT));
-      }
-    }
-#endif
   }
   
   *reference = pt;
@@ -294,6 +280,7 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
   
   if(!read_proc_file(buf, 1024, "meminfo", -1))
   {
+    log("system statistic error -- cannot get real memory free amount\n");
     goto error;
   }
 
@@ -361,6 +348,7 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
 
   if(!read_proc_file(buf, 1024, "stat", -1))
   {
+    log("system statistic error -- cannot read /proc/stat\n");
     goto error;
   }
 
