@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -24,6 +24,10 @@
 #include <string.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -65,7 +69,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala<martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_OPENBSD.c,v 1.22 2004/09/10 23:15:27 martinp Exp $
+ *  @version \$Id: sysdep_OPENBSD.c,v 1.24 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
