@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -24,6 +24,10 @@
 #include <stdio.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -86,7 +90,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: sysdep_SOLARIS.c,v 1.14 2004/09/09 20:46:19 martinp Exp $
+ *  @version \$Id: sysdep_SOLARIS.c,v 1.17 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -134,7 +138,7 @@ double timestruc_to_tseconds(timestruc_t t) {
 
 
 /**
- * Read all processes of the proc files system to initilize
+ * Read all processes of the proc files system to initialize
  * the process tree (sysdep version... but should work for
  * all procfs based unices)
  * @param reference  reference of ProcessTree
