@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: sysdep_UNKNOWN.c,v 1.7 2004/09/09 20:17:42 martinp Exp $
+ *  @version \$Id: sysdep_UNKNOWN.c,v 1.10 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -48,7 +48,7 @@ int init_process_info_sysdep(void) {
 /**
  * THIS IS JUST A DUMMY!!!
  *
- * Read all processes of the proc files system to initilize
+ * Read all processes of the proc files system to initialize
  * the process tree (sysdep version... but should work for
  * all procfs based unices) 
  * @param reference  reference of ProcessTree
@@ -99,7 +99,7 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
  * This routine returns system/user CPU time in use.
  * @return: TRUE if successful, FALSE if failed (or not available)
  */
-int used_system_cpu_sysdep(SystemInfo *si) {
+int used_system_cpu_sysdep(SystemInfo_T *si) {
 
   return FALSE;
   
