@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -63,7 +63,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: dwp.c,v 1.11 2004/06/10 09:57:00 chopp Exp $
+ *  @version \$Id: dwp.c,v 1.14 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -89,9 +89,8 @@ int check_dwp(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf,STRLEN);
+  Util_chomp(buf);
 
-  /* RATS: ignore */ /* chomp does zero termination */
   n= sscanf(buf, "%s %d", proto, &status);
   if(n!=2 || (status >= 400)) {
     log("DWP error: %s\n", buf);
