@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Michael Amster, <mamster@webeasy.com>
  *
- *  @version \$Id: ftp.c,v 1.15 2004/02/18 22:31:42 chopp Exp $
+ *  @version \$Id: ftp.c,v 1.18 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -57,9 +57,8 @@ int check_ftp(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
+  Util_chomp(buf);
   
-  /* RATS: ignore */ /* chomp does zero termination */
   sscanf(buf, "%d %s", &status, msg);
   if(status != 220) {
     log("FTP error: %s\n", buf);
@@ -68,7 +67,7 @@ int check_ftp(Socket_T s) {
 
   /* Read past banners */
   while(NULL != socket_readln(s, buf, STRLEN)) {
-    if(starts_with(buf, "220")) continue;
+    if(Util_startsWith(buf, "220")) continue;
   }
   
   if(socket_print(s, "QUIT\r\n") < 0) {
@@ -81,9 +80,8 @@ int check_ftp(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
-  
-  /* RATS: ignore */ /* chomp does zero termination */
+  Util_chomp(buf);
+
   sscanf(buf, "%d %s", &status, msg);
   if(status != 221) {
     log("FTP error: %s\n", buf);
