@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -43,7 +43,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: pop.c,v 1.14 2004/02/18 22:31:42 chopp Exp $
+ *  @version \$Id: pop.c,v 1.17 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -59,7 +59,7 @@ int check_pop(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
+  Util_chomp(buf);
   
   if(strncasecmp(buf, ok, strlen(ok)) != 0) {
     log("POP error: %s\n", buf);
@@ -76,7 +76,7 @@ int check_pop(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
+  Util_chomp(buf);
   
   if(strncasecmp(buf, ok, strlen(ok)) != 0) {
     log("POP error: %s\n", buf);
