@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -48,6 +48,8 @@ static Protocol_T myldap3= NULL;
 static Protocol_T myrdate= NULL;
 static Protocol_T myrsync= NULL;
 static Protocol_T mygeneric= NULL;
+static Protocol_T myapache_status= NULL;
+static Protocol_T myntp3= NULL;
 
 
 /**
@@ -56,7 +58,7 @@ static Protocol_T mygeneric= NULL;
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: protocol.c,v 1.18 2004/01/29 17:52:12 martinp Exp $
+ *  @version \$Id: protocol.c,v 1.21 2005/01/28 17:54:33 martinp Exp $
  *
  *  @file
  */
@@ -81,188 +83,168 @@ void gc_protocols() {
   FREE(myrdate);   
   FREE(myrsync);   
   FREE(mygeneric); 
+  FREE(myapache_status);
+  FREE(myntp3);
 
 }
 
 
 void *create_default() {
-
   if(mydefault == NULL) {
     NEW(mydefault);
     mydefault->name= "DEFAULT";
     mydefault->check= check_default;
   }
-
   return mydefault;
-
 }
 
 
 void *create_http() {
-
   if(myhttp == NULL) {
     NEW(myhttp);
     myhttp->name= "HTTP";
     myhttp->check= check_http;
   }
-
   return myhttp;
+}
 
+
+void *create_apache_status() {
+  if(myapache_status == NULL) {
+    NEW(myapache_status);
+    myapache_status->name= "APACHESTATUS";
+    myapache_status->check= check_apache_status;
+  }
+  return myapache_status;
 }
 
 
 void *create_ftp() {
-
   if(myftp == NULL) {
     NEW(myftp);
     myftp->name= "FTP";
     myftp->check= check_ftp;
   }
-
   return myftp;
-
 }
 
 
 void *create_smtp() {
-
   if(mysmtp == NULL) {
     NEW(mysmtp);
     mysmtp->name= "SMTP";
     mysmtp->check= check_smtp;
   }
-
   return mysmtp;
-
 }
 
 
 void *create_pop() {
-
   if(mypop == NULL) {
     NEW(mypop);
     mypop->name= "POP";
     mypop->check= check_pop;
   }
-
   return mypop;
-
 }
 
 
 void *create_imap() {
-
   if(myimap == NULL) {
     NEW(myimap);
     myimap->name= "IMAP";
     myimap->check= check_imap;
   }
-
   return myimap;
+}
 
+
+void *create_ntp3() {
+  if(myntp3 == NULL) {
+    NEW(myntp3);
+    myntp3->name= "NTP3";
+    myntp3->check= check_ntp3;
+  }
+  return myntp3;
 }
 
 
 void *create_nntp() {
-
   if(mynntp == NULL) {
     NEW(mynntp);
     mynntp->name= "NNTP";
     mynntp->check= check_nntp;
   }
-
   return mynntp;
-
 }
 
 
 void *create_ssh() {
-  
   if(myssh == NULL) {
     NEW(myssh);
     myssh->name= "SSH";
     myssh->check= check_ssh;
   }
-  
   return myssh;
-
 }
 
 
 void *create_dwp() {
-  
   if(mydwp == NULL) {
     NEW(mydwp);
     mydwp->name= "DWP";
     mydwp->check= check_dwp;
   }
-  
   return mydwp;
-
 }
 
 
 void *create_ldap2() {
-  
   if(myldap2 == NULL) {
     NEW(myldap2);
     myldap2->name= "LDAP2";
     myldap2->check= check_ldap2;
   }
-  
   return myldap2;
-
 }
 
 
 void *create_ldap3() {
-  
   if(myldap3 == NULL) {
     NEW(myldap3);
     myldap3->name= "LDAP3";
     myldap3->check= check_ldap3;
   }
-  
   return myldap3;
-
 }
 
 
 void *create_rdate() {
-  
   if(myrdate == NULL) {
     NEW(myrdate);
     myrdate->name= "RDATE";
     myrdate->check= check_rdate;
   }
-  
   return myrdate;
-  
 }
 
 
 void *create_rsync() {
-  
   if(myrsync == NULL) {
     NEW(myrsync);
     myrsync->name= "RSYNC";
     myrsync->check= check_rsync;
   }
-  
   return myrsync;
-  
 }
 
 void *create_generic() {
-  
-  if(myrsync == NULL) {
-    NEW(myrsync);
-    myrsync->name= "generic";
-    myrsync->check= check_generic;
+  if(mygeneric == NULL) {
+    NEW(mygeneric);
+    mygeneric->name= "generic";
+    mygeneric->check= check_generic;
   }
-  
-  return myrsync;
-  
+  return mygeneric;
 }
 
 
