@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -18,8 +18,8 @@
  */
 
 
-#ifndef PROTOCOL_H
-#define PROTOCOL_H
+#ifndef MONIT_PROTOCOL_H
+#define MONIT_PROTOCOL_H
 
 #include <config.h>
 
@@ -27,29 +27,33 @@
 #include "socket.h"
 
 /* Protocols supported */
-#define P_DEFAULT  1
-#define P_HTTP     2
-#define P_FTP      3
-#define P_SMTP     4
-#define P_POP      5
-#define P_IMAP     6
-#define P_NNTP     7
-#define P_SSH      8
-#define P_DWP      9
-#define P_LDAP2    10
-#define P_LDAP3    11
-#define P_RDATE    12
-#define P_RSYNC    13
-#define P_GENERIC  14
+#define P_DEFAULT         1
+#define P_HTTP            2
+#define P_FTP             3
+#define P_SMTP            4
+#define P_POP             5
+#define P_IMAP            6
+#define P_NNTP            7
+#define P_SSH             8
+#define P_DWP             9
+#define P_LDAP2          10
+#define P_LDAP3          11
+#define P_RDATE          12
+#define P_RSYNC          13
+#define P_GENERIC        14
+#define P_APACHESTATUS   15
+#define P_NTP3           16
+
+void  gc_protocols();
 
 /* Protocol Factory routines */
-void  gc_protocols();
 void* create_default();
 void* create_http();
 void* create_ftp();
 void* create_smtp();
 void* create_pop();
 void* create_imap();
+void* create_ntp3();
 void* create_nntp();
 void* create_ssh();
 void* create_dwp();
@@ -58,6 +62,7 @@ void* create_ldap3();
 void* create_rdate();
 void* create_rsync();
 void* create_generic();
+void* create_apache_status();
 
 /* "Package" locale Protocol routines */
 int check_default(Socket_T);
@@ -68,10 +73,14 @@ int check_ftp(Socket_T);
 int check_http(Socket_T);
 int check_smtp(Socket_T);
 int check_imap(Socket_T);
+int check_ntp3(Socket_T);
 int check_nntp(Socket_T);
 int check_ldap2(Socket_T);
 int check_ldap3(Socket_T);
 int check_rdate(Socket_T);
 int check_rsync(Socket_T);
 int check_generic(Socket_T);
+int check_apache_status(Socket_T);
+
+
 #endif
