@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
  * 
  *  @author Igor Homyakov <homyakov@altlinux.ru>
  *
- *  @version \$Id: rsync.c,v 1.7 2004/02/18 22:31:42 chopp Exp $
+ *  @version \$Id: rsync.c,v 1.10 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -58,9 +58,8 @@ int check_rsync(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
+  Util_chomp(buf);
   
-  /* RATS: ignore */ /* chomp does zero termination */
   rc = sscanf(buf, "%s %d", msg, &version);
   if ((rc == EOF) || (rc == 0)) {
      log("RSYNC: server greeting parse error %s\n", buf);
