@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Michael Amster, <mamster@webeasy.com>
  *
- *  @version \$Id: smtp.c,v 1.14 2004/02/18 22:31:42 chopp Exp $
+ *  @version \$Id: smtp.c,v 1.17 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -57,9 +57,8 @@ int check_smtp(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
+  Util_chomp(buf);
   
-  /* RATS: ignore */ /* chomp does zero termination */
   sscanf(buf, "%d %s", &status, msg);
   if(status != 220) {
     log("SMTP error: %s\n", buf);
@@ -76,9 +75,8 @@ int check_smtp(Socket_T s) {
     return FALSE;
   }
 
-  chomp(buf, STRLEN);
+  Util_chomp(buf);
   
-  /* RATS: ignore */ /* chomp does zero termination */
   sscanf(buf, "%d %s", &status, msg);
   if(status != 221) {
     log("SMTP error: %s\n", buf);
