@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@
  * 
  *  @author Igor Homyakov, <homyakov@altlinux.ru>
  *
- *  @version \$Id: ssh.c,v 1.8 2004/01/29 17:52:12 martinp Exp $
+ *  @version \$Id: ssh.c,v 1.10 2005/01/06 20:51:50 martinp Exp $
  *
  *  @file
  */
@@ -53,7 +53,7 @@ int check_ssh(Socket_T s) {
     return FALSE;
   }
   
-  if(! starts_with(buf, "SSH-")) {
+  if(! Util_startsWith(buf, "SSH-")) {
     log("SSH: protocol error %s\n", buf);
     return FALSE;
   }
