@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -50,7 +50,7 @@
  * Implementation of the socket interface.
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.c,v 1.35 2004/05/15 20:03:53 martinp Exp $
+ * @version \$Id: socket.c,v 1.40 2005/02/12 23:44:07 martinp Exp $
  * @file
  */
 
@@ -86,12 +86,16 @@ struct Socket_T {
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
  * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
- * @param use_ssl if TRUE the socket is created supporting SSL
+ * @param use_ssl If TRUE the socket is created supporting SSL
+ * @param timeout The timeout value in seconds
  * @return The connected Socket or NULL if an error occurred
  */
-Socket_T socket_new(const char *host, int port, int type, int use_ssl) {
+Socket_T socket_new(const char *host, int port, int type, int use_ssl,
+                    int timeout) {
 
-  return socket_create_t(host, port, type, use_ssl, NET_TIMEOUT);
+  Ssl_T ssl= {use_ssl, SSL_VERSION_AUTO, NULL};
+
+  return socket_create_t(host, port, type, ssl, timeout);
   
 }
 
@@ -104,13 +108,14 @@ Socket_T socket_new(const char *host, int port, int type, int use_ssl) {
 Socket_T socket_create(void *port) {
 
   int s;
-  Socket_T S;
   Port_T p= port;
 
   ASSERT(port);
 
   if((s= create_generic_socket(p)) != -1) {
 
+    Socket_T S= NULL;
+
     NEW(S);
     S->socket= s;
     S->type= p->type;
@@ -155,7 +160,7 @@ Socket_T socket_create(void *port) {
 
 /**
  * Create a new Socket opened against host:port with an explicit
- * timeout value for connect and read. Otherwise, same as socket_new()
+ * ssl value for connect and read. Otherwise, same as socket_new()
  * @param host The remote host to open the Socket against. The host
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
@@ -164,22 +169,23 @@ Socket_T socket_create(void *port) {
  * @param timeout The timeout value in seconds
  * @return The connected Socket or NULL if an error occurred
  */
-Socket_T socket_create_t(const char *host, int port, int type, int use_ssl,
+Socket_T socket_create_t(const char *host, int port, int type, Ssl_T ssl,
 			 int timeout) {
 
   int s;
-  Socket_T S;
   int proto= type==SOCKET_UDP?SOCK_DGRAM:SOCK_STREAM;
   
   ASSERT(host);
   ASSERT((type==SOCKET_UDP)||(type==SOCKET_TCP));
-  if(use_ssl) {
+  if(ssl.use_ssl) {
     ASSERT(type==SOCKET_TCP);
   }
   ASSERT(timeout>0);
 
   if((s= create_socket(host, port, proto, timeout)) != -1) {
     
+    Socket_T S= NULL;
+ 
     NEW(S);
     S->socket= s;
     S->port= port;
@@ -188,13 +194,18 @@ Socket_T socket_create_t(const char *host, int port, int type, int use_ssl,
     S->host= xstrdup(host);
     S->connection_type= TYPE_LOCAL;
     
-    if(use_ssl) {
-      if(! (S->ssl= new_ssl_connection(NULL, SSL_VERSION_AUTO))) {
+    if(ssl.use_ssl) {
+      if(! (S->ssl= new_ssl_connection(NULL, ssl.version))) {
 	goto ssl_error;
       }
       if(! embed_ssl_socket(S->ssl, S->socket)) {
 	goto ssl_error;
       }
+      if(ssl.certmd5) {
+	if(! check_ssl_md5sum(S->ssl, ssl.certmd5)) {
+	  goto ssl_error;
+	}
+      }
     }
     
     return S;
@@ -299,9 +310,15 @@ int socket_is_ready(Socket_T S) {
   ASSERT(S);
   
   switch(S->type) {
-  case SOCK_STREAM: return check_socket(S->socket);
-  case SOCK_DGRAM:  return check_udp_socket(S->socket);
-  default:          break;
+
+    case SOCK_STREAM:
+      return check_socket(S->socket);
+
+    case SOCK_DGRAM:
+      return check_udp_socket(S->socket);
+
+    default:
+      break;
   }
 
   return FALSE;
@@ -388,7 +405,7 @@ int socket_print(Socket_T S, const char *m, ...) {
   ASSERT(m);
 
   va_start(ap, m);
-  buf= format(m, ap, &l);
+  buf= Util_formatString(m, ap, &l);
   va_end(ap);
   
   n= socket_write(S, buf, l);
