@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@
  * communication between two machines. 
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.h,v 1.15 2004/01/29 17:52:11 martinp Exp $
+ * @version \$Id: socket.h,v 1.17 2005/01/06 20:51:49 martinp Exp $
  * @file
  */
 
@@ -49,9 +49,11 @@ typedef struct Socket_T *Socket_T;
  * @param port The port number to connect to
  * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
  * @param use_ssl if TRUE the socket is created supporting SSL
+ * @param timeout The timeout value in seconds
  * @return The connected Socket or NULL if an error occurred
  */
-Socket_T socket_new(const char *host, int port, int type, int use_ssl);
+Socket_T socket_new(const char *host, int port, int type, int use_ssl,
+                    int timeout);
 
 
 /**
@@ -64,16 +66,16 @@ Socket_T socket_create(void *port);
 
 /**
  * Create a new Socket opened against host:port with an explicit
- * timeout value for connect and read. Otherwise, same as socket_new()
+ * ssl value for connect and read. Otherwise, same as socket_new()
  * @param host The remote host to open the Socket against. The host
  * may be a hostname found in the DNS or an IP address string.
  * @param port The port number to connect to
  * @param type The socket type to use (SOCKET_TCP or SOCKET_UPD)
- * @param use_ssl if TRUE the socket is created supporting SSL
+ * @param ssl If defined the socket is created supporting SSL
  * @param timeout The timeout value in seconds
  * @return The connected Socket or NULL if an error occurred
  */
-Socket_T socket_create_t(const char *host, int port, int type, int use_ssl,
+Socket_T socket_create_t(const char *host, int port, int type, Ssl_T ssl,
 			 int timeout);
 
 
