@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -105,7 +105,7 @@ static int ssl_entropy_stop(void);
 
 static pthread_mutex_t   ssl_mutex= PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t *ssl_mutex_table;
-static int ssl_initilized= FALSE;
+static int ssl_initialized= FALSE;
 
 /* Connection verification code */
 static int verify_init(ssl_server_connection *);
@@ -150,7 +150,7 @@ static void handle_ssl_error(char *);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: ssl.c,v 1.36 2004/02/18 22:31:42 chopp Exp $
+ *  @version \$Id: ssl.c,v 1.40 2005/02/15 19:20:09 martinp Exp $
  *
  *  @file
  */
@@ -187,7 +187,7 @@ int embed_ssl_socket (ssl_connection *ssl, int socket) {
     
   }
   
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
     
     start_ssl();
 
@@ -370,7 +370,7 @@ ssl_connection *create_ssl_socket(char *hostname, int port, int protocol, int ss
 
   ASSERT(hostname);
 
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
 
     start_ssl();
 
@@ -586,7 +586,7 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
 
   ASSERT(pemfile);
 
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
 
     start_ssl();
 
@@ -646,7 +646,7 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
 
     handle_ssl_error("init_ssl_server()");
     log("%s: init_ssl_server(): Verification engine was not"
-	  " properly initilized!\n", prog);
+	  " properly initialized!\n", prog);
     goto sslerror;
 
   }
@@ -696,7 +696,7 @@ ssl_server_connection *create_ssl_server_socket(char *pemfile, int port,
   ASSERT(pemfile);
   ASSERT(bindAddr);
 
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
 
     start_ssl();
 
@@ -862,7 +862,7 @@ ssl_connection *insert_accepted_ssl_socket(ssl_server_connection *ssl_server) {
 
   ASSERT(ssl_server);
 
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
 
     start_ssl();
 
@@ -1030,7 +1030,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
   
   ssl->socket=socket;
 
-  if(!ssl_initilized) {
+  if(!ssl_initialized) {
 
     start_ssl();
 
@@ -1259,9 +1259,9 @@ int start_ssl() {
 
 #ifdef HAVE_OPENSSL
 
-  if (! ssl_initilized ) {
+  if (! ssl_initialized ) {
 
-    ssl_initilized=TRUE;
+    ssl_initialized=TRUE;
     ERR_load_crypto_strings();
     return (ssl_thread_start() && SSL_library_init() && ssl_entropy_start());
 
@@ -1288,9 +1288,9 @@ int stop_ssl() {
 
 #ifdef HAVE_OPENSSL
 
-  if ( ssl_initilized ) {
+  if ( ssl_initialized ) {
 
-    ssl_initilized=FALSE;
+    ssl_initialized=FALSE;
     ERR_free_strings();
     return (ssl_thread_stop() && ssl_entropy_stop());
 
@@ -1334,7 +1334,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
 
   ssl_connection *ssl = (ssl_connection *) NEW(ssl);
 
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
 
     start_ssl();
 
@@ -1392,7 +1392,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
   if (ssl->method == NULL ) {
 
     handle_ssl_error("new_ssl_connection()");
-    log("%s: new_ssl_connection(): Cannot initilize SSL method!\n", prog);
+    log("%s: new_ssl_connection(): Cannot initialize SSL method!\n", prog);
     goto sslerror;
 
   } 
@@ -1400,7 +1400,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
   if ((ssl->ctx= SSL_CTX_new (ssl->method)) == NULL ) {
 
     handle_ssl_error("new_ssl_connection()");
-    log("%s: new_ssl_connection(): Cannot initilize SSL server certificate"
+    log("%s: new_ssl_connection(): Cannot initialize SSL server certificate"
 	  " handler!\n", prog);
     goto sslerror;
 
@@ -1412,7 +1412,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
 				     SSL_FILETYPE_PEM) <= 0) {
 
       handle_ssl_error("new_ssl_connection()");
-      log("%s: new_ssl_connection(): Cannot initilize SSL server"
+      log("%s: new_ssl_connection(): Cannot initialize SSL server"
 	    " certificate!\n", prog);
       goto sslerror;
       
@@ -1422,7 +1422,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
 				    SSL_FILETYPE_PEM) <= 0) {
 
       handle_ssl_error("new_ssl_connection()");
-      log("%s: new_ssl_connection(): Cannot initilize SSL server"
+      log("%s: new_ssl_connection(): Cannot initialize SSL server"
 	    " private key!\n", prog);
       goto sslerror;
 
@@ -1472,7 +1472,7 @@ ssl_server_connection *new_ssl_server_connection(char * pemfile,
 
   ASSERT(pemfile);
 
-  if (!ssl_initilized) {
+  if (!ssl_initialized) {
 
     start_ssl();
 
@@ -1840,8 +1840,7 @@ static int ssl_thread_stop(void) {
   CRYPTO_set_locking_callback(NULL);
   for(i= 0; i < CRYPTO_num_locks(); i++)
       pthread_mutex_destroy(&ssl_mutex_table[i]);
-  free(ssl_mutex_table);
-  ssl_mutex_table= NULL;
+  FREE(ssl_mutex_table);
 
   return TRUE;
 
@@ -1854,11 +1853,11 @@ static int ssl_thread_stop(void) {
  */
 static int ssl_entropy_start(void) {
 
-  if(exist_file(URANDOM_DEVICE)) {
+  if(File_exist(URANDOM_DEVICE)) {
 
     return(RAND_load_file(URANDOM_DEVICE, RANDOM_BYTES)==RANDOM_BYTES);
 
-  } else if(exist_file(RANDOM_DEVICE)) {
+  } else if(File_exist(RANDOM_DEVICE)) {
 
     fprintf(stdout, "Gathering entropy from the random device. Please wait\n");
     fflush(stdout);
