@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -35,6 +35,13 @@
 #define SSL_VERSION_SSLV3      2
 #define SSL_VERSION_TLS        3
 
+/** Defines an SSL object */
+typedef struct myssl {
+  int   use_ssl;                 /**< TRUE if SSL is required for connection */
+  int   version;                  /**< The SSL version to use for connection */
+  char *certmd5;       /**< The expected md5 sum of the server's certificate */
+} Ssl_T;
+
 #ifdef HAVE_OPENSSL
 typedef struct my_ssl_connection {
 
