@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -52,6 +52,7 @@
 #endif
 
 #include "monitor.h"
+#include "state.h"
 
 
 /**
@@ -63,7 +64,7 @@
  *  file, if not set, the default is ~/.monit.state.
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- *  @version \$Id: state.c,v 1.22 2004/08/04 22:02:09 martinp Exp $
+ *  @version \$Id: state.c,v 1.24 2005/01/06 20:51:49 martinp Exp $
  *  @file
  */
 
@@ -100,7 +101,7 @@ static void update_service_state(Service_T, State_T *);
 /**
  * Save service state information to the state file
  */
-void state_save() {
+void State_save() {
 
   int l= 0;
   Service_T s;
@@ -113,7 +114,7 @@ void state_save() {
 
   set_signal_block(&ns, &os);
 
-  l= get_service_list_length();
+  l= Util_getNumberOfServices();
   
   if(fwrite(&l, 1, sizeof (int), S) != sizeof(int)) {
     log("%s: Unable to save monit state information to '%s'\n",
@@ -144,15 +145,13 @@ void state_save() {
  * crash and should update data from the state file.
  * @return TRUE if the state should be updated otherwise FALSE
  */
-int state_should_update() {
-
-  if(exist_file(Run.statefile) && exist_file(Run.pidfile)) {
-    
-    return (get_timestamp(Run.pidfile, S_IFREG) >
-	    get_timestamp(Run.statefile, S_IFREG));
-    
+int State_shouldUpdate() {
+  
+  if(File_exist(Run.statefile) && File_exist(Run.pidfile)) {
+    return (File_getTimestamp(Run.pidfile, S_IFREG) >
+	    File_getTimestamp(Run.statefile, S_IFREG));
   }
-
+  
   return FALSE;
   
 }
@@ -180,7 +179,7 @@ int state_should_update() {
  * Finally, after the monit service state is updated this function
  * writes the new state file.
  */
-void state_update() {
+void State_update() {
 
   int i;
   int l= 0;
@@ -211,7 +210,7 @@ void state_update() {
 	has_error= TRUE;
 	goto error;
       }
-      if((service= get_service(s.name))) {
+      if((service= Util_getService(s.name))) {
 	update_service_state(service, &s);
       }
     }
@@ -222,7 +221,7 @@ void state_update() {
   unset_signal_block(&os);
 
   if(!has_error)
-      state_save();
+      State_save();
 
 }
 
