@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -86,6 +86,14 @@
 #include <crypt.h>
 #endif
 
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+
+#ifdef HAVE_ARPA_INET_H
+#include <arpa/inet.h>
+#endif
+
 #include "monitor.h"
 #include "engine.h"
 #include "md5.h"
@@ -98,8 +106,8 @@
 /* Private prototypes */
 static char x2c(char *hex);
 static char *is_str_defined(char *);
-static int is_unsafe(unsigned char *);
 static void printevents(unsigned int);
+static int is_url_unsafe(unsigned char *);
 
 
 /**
@@ -110,7 +118,7 @@ static void printevents(unsigned int);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.c,v 1.130 2004/08/18 07:03:43 martinp Exp $
+ *  @version \$Id: util.c,v 1.155 2005/03/23 23:37:49 hauk Exp $
  *  @file
  */
 
@@ -119,21 +127,12 @@ static void printevents(unsigned int);
 
 
 /**
- * @return TRUE if the string parameter is defined, otherwise FALSE
- */
-int is_strdefined(char *p) {
-  
-  return(p && *p);
-  
-}
-
-
-/**
- * Strip the path and return only the filename
+ * Return only the filename with leading directory components
+ * removed. This function does not modify the path string.
  * @param path A file path string
- * @return the basename
+ * @return A pointer to the basename in path
  */
-char *stripfilename(char* path) {
+char *Util_basename(char* path) {
   
   char *fname;
 
@@ -147,38 +146,36 @@ char *stripfilename(char* path) {
 
 
 /**
- * Removes everything from the first newline (CR|LF)
- * @param string A string to be chomped
- */
-void chomp(char *string, int len) {
+  * Removes everything from the first line break or newline (CR|LF)
+  * @param s A string to be chomped
+  * @return The chomped string
+  */
+char *Util_chomp(char *s) {
+
+  ASSERT(s);
   
-  char *p=string;
-  int   i;
-
-  ASSERT(string);
-
-  for (i=0;i<len;i++,p++) {
-    if((*p== '\r') || (*p=='\n')) {
-      *p= 0;
-      return;
+  for (; *s; s++) {
+    if (('\r' == *s) || ('\n' == *s)) {
+      *s= 0; break;
     }
   }
+
+  return s;
   
-  string[len-1]=0;
 }
 
 
 /**
  * Remove leading and trailing space from the string
  * @param s A string
- * @return s with leading and trailing spaces removed
+ * @return s with leading and trailing spaces removed 
  */
-char *trim(char *s) {
+char *Util_trim(char *s) {
 
   ASSERT(s);
   
-  ltrim(s);
-  rtrim(s);
+  Util_ltrim(s);
+  Util_rtrim(s);
 
   return s;
   
@@ -190,15 +187,21 @@ char *trim(char *s) {
  * @param s A string
  * @return s with leading spaces removed
  */
-char *ltrim(char *s) {
-
+char *Util_ltrim(char *s) {
+  
   char *t= s;
 
   ASSERT(s);
 
   while(*t==' ' || *t=='\t' || *t=='\r' || *t=='\n') t++;
+  if(t!=s) {
+    char *r= s;
+    do {
+      *r++= *t;
+    } while(*t++);
+  }
 
-  return strcpy(s, t);
+  return s;
 
 }
 
@@ -208,15 +211,15 @@ char *ltrim(char *s) {
  * @param s A string
  * @return s with trailing spaces removed
  */
-char *rtrim(char *s) {
+char *Util_rtrim(char *s) {
 
   char *t= s;
 
   ASSERT(s);
 
   while(*s) s++;
-  while(*--s==' ' || *s=='\t' || *s=='\r' || *s=='\n') *s= '\0';
-
+  while(*--s==' ' || *s=='\t' || *s=='\r' || *s=='\n') *s= 0;
+  
   return t;
 
 }
@@ -224,10 +227,8 @@ char *rtrim(char *s) {
 /**
  * Remove any enclosing quotes ["'] from the string
  * @param s A string
- * @return s with any enclosed quotes removed
  */
-
-void trim_quotes(char *s) {
+void Util_trimQuotes(char *s) {
 
   char *t= s;
   char tmp=0;
@@ -246,10 +247,8 @@ void trim_quotes(char *s) {
   }
 
   while ( *t != tmp && *t != '\0' ) {
-
     *(t-1) = *t;
     t++;
-    
   }
 
   *(t-1) = '\0';
@@ -267,7 +266,7 @@ void trim_quotes(char *s) {
  * @param new The new char
  * @return s where all occurrence of old are replaced with new
  */
-char *replace_char(char *s, char old, char new) {
+char *Util_replace(char *s, char old, char new) {
 
   char *t= s;
 
@@ -289,28 +288,28 @@ char *replace_char(char *s, char old, char new) {
  * @return src where all occurrences of the old sub-string are
  * replaced with the new sub-string. 
  */
-char *replace_string(char **src, const char *old, const char *new) {
+char *Util_replaceString(char **src, const char *old, const char *new) {
 
   int i;
   int d;
-
+  
   ASSERT(src && *src && old && new);
   
-  i= count_words(*src, old);
+  i= Util_countWords(*src, old);
   d= strlen(new)-strlen(old);
   
   if(i==0)
-      return *src;
+    return *src;
   if(d>0)
-      d*= i;
+    d*= i;
   else
-      d= 0;
+    d= 0;
   
   {
     char *p, *q;
     int l= strlen(old);
-    char *buf= xmalloc(strlen(*src)+d+1);
-
+    char *buf= xcalloc(sizeof(char), strlen(*src)+d+1);
+    
     q= *src;
     *buf= 0;
     
@@ -328,7 +327,7 @@ char *replace_string(char **src, const char *old, const char *new) {
     FREE(*src);
     *src= buf;
   }
-
+  
   return *src;
   
 }
@@ -339,7 +338,7 @@ char *replace_string(char **src, const char *old, const char *new) {
  * @param s The String to search for word in
  * @param word 	The sub-string to count in s
  */
-int count_words(char *s, const char *word) {
+int Util_countWords(char *s, const char *word) {
 
   int i= 0;
   char *p= s;
@@ -362,9 +361,9 @@ int count_words(char *s, const char *word) {
  * @param b The sub-string to test a against
  * @return TRUE if a starts with b, otherwise FALSE
  */
-int starts_with(const char *a, const char *b) {
+int Util_startsWith(const char *a, const char *b) {
 
-  if((!a || !b) || *a!=*b) return FALSE;
+  if((!a || !b) || toupper(*a)!=toupper(*b)) return FALSE;
 
   while(*a && *b) {
     
@@ -381,19 +380,19 @@ int starts_with(const char *a, const char *b) {
  * Exchanges \escape sequences in a string
  * @param buf A string
  */
-void handle_string_escapes(char *buf) {
+void Util_handleEscapes(char *buf) {
 
   int editpos;
   int insertpos;
 
   ASSERT(buf);
-
+  
   for(editpos=insertpos=0; *(buf+editpos)!='\0'; editpos++, insertpos++) {
-
+    
     if(*(buf+editpos) == '\\' ) {
       
       switch(*(buf+editpos+1)) {
-
+	
       case 'n': 
         *(buf+insertpos)='\n';
         editpos++;
@@ -440,7 +439,7 @@ void handle_string_escapes(char *buf) {
  * @param name A service name as stated in the config file
  * @return the named service or NULL if not found
  */
-Service_T get_service(const char *name) {
+Service_T Util_getService(const char *name) {
 
   Service_T s;
 
@@ -457,12 +456,25 @@ Service_T get_service(const char *name) {
 }
 
 
+/**
+ * Get the length of the service list, that is; the number of services
+ * managed by monit
+ * @return The number of services monitored
+ */
+int Util_getNumberOfServices() {
+  int i= 0;
+  Service_T s;
+  for(s= servicelist; s; s= s->next) i+=1;
+  return i;
+}
+
+
 /**
  * @param name A service name as stated in the config file
  * @return TRUE if the service name exist in the
  * servicelist, otherwise FALSE
  */
-int exist_service(const char *name) {
+int Util_existService(const char *name) {
 
   Service_T s;
 
@@ -477,27 +489,10 @@ int exist_service(const char *name) {
 }
 
 
-/**
- * Get the length of the service list, that is; the number of
- * services in the list.
- * @return The length of the service list
- */
-int get_service_list_length() {
-
-  int i= 0;
-  Service_T s;
-
-  for(s= servicelist; s; s= s->next) i+=1;
-
-  return i;
-
-}
-
-
 /**
  * Print the Runtime object
  */
-void printrunlist() {
+void Util_printRunList() {
   
   printf("Runtime constants:\n");
   printf(" %-18s = %s\n", "Control file", is_str_defined(Run.controlfile));
@@ -509,8 +504,26 @@ void printrunlist() {
   printf(" %-18s = %s\n", "Is Daemon", Run.isdaemon?"True":"False");
   printf(" %-18s = %s\n", "Use process engine", Run.doprocess?"True":"False");
   printf(" %-18s = %d seconds\n", "Poll time", Run.polltime);
-  printf(" %-18s = ", "Mail server(s)");
 
+  if(Run.collectors) {
+    Collector_T c= Run.collectors;
+    printf(" %-18s = ", "Collector(s)");
+    for(c= Run.collectors; c; c= c->next)
+    {
+      printf("%s with timeout %d seconds%s%s%s%s%s%s",
+        c->url->url,
+        c->timeout,
+	c->ssl.use_ssl?" ssl version ":"",
+	c->ssl.use_ssl?sslnames[c->ssl.version]:"",
+	c->ssl.certmd5?" server cert md5 sum ":"",
+	c->ssl.certmd5?c->ssl.certmd5:"",
+        c->url->user?" using credentials":"",
+        c->next?",\n                    = ":"");
+    }
+    printf("\n");
+  }
+
+  printf(" %-18s = ", "Mail server(s)");
   if(Run.mailservers) {
     MailServer_T mta= Run.mailservers;
     for(mta= Run.mailservers; mta; mta= mta->next)
@@ -555,9 +568,9 @@ void printrunlist() {
 
     printf(" %-18s = %s\n", "httpd auth. style",
 	   (Run.credentials!=NULL)&&has_hosts_allow()?
-	   "Basic Authentication and Host allow list":
+	   "Basic Authentication and Host/Net allow list":
 	   (Run.credentials!=NULL)?"Basic Authentication":
-	   has_hosts_allow()?"Host allow list":
+	   has_hosts_allow()?"Host/Net allow list":
 	   "No authentication!");
      
   }
@@ -580,7 +593,7 @@ void printrunlist() {
  * Print a service object
  * @param p A Service_T object
  */
-void printservice(Service_T s) {
+void Util_printService(Service_T s) {
   
   Port_T n;
   Icmp_T i;
@@ -623,6 +636,13 @@ void printservice(Service_T s) {
     if(d->dependant != NULL)
       printf(" %-20s = %s\n", "Depends on Service", d->dependant);
 
+  if(s->type == TYPE_PROCESS) {
+    printf(" %-20s = if changed then %s\n",
+      "Pid", actionnames[s->action_PID->failed->id]);
+    printf(" %-20s = if changed then %s\n",
+      "Ppid", actionnames[s->action_PPID->failed->id]);
+  }
+
   if(s->checksum && s->checksum->action) {
     Checksum_T cs= s->checksum;
     EventAction_T a= cs->action;
@@ -742,21 +762,35 @@ void printservice(Service_T s) {
     
     if(dl->resource == RESOURCE_ID_INODE) {
 	    
-      printf(" %-20s = if %s %ld %s then %s else if recovered then %s\n",
-        "Inodes usage limit",
-        operatornames[dl->operator],
-        (dl->limit_absolute > -1)?dl->limit_absolute:dl->limit_percent,
-        (dl->limit_absolute > -1)?"":"%",
-        actionnames[a->failed->id], actionnames[a->passed->id]);
+      if(dl->limit_absolute > -1) {
+        printf(" %-20s = if %s %ld then %s else if recovered then %s\n",
+          "Inodes usage limit",
+          operatornames[dl->operator],
+          dl->limit_absolute,
+          actionnames[a->failed->id], actionnames[a->passed->id]);
+      } else {
+        printf(" %-20s = if %s %.1f%% then %s else if recovered then %s\n",
+          "Inodes usage limit",
+          operatornames[dl->operator],
+          dl->limit_percent/10.,
+          actionnames[a->failed->id], actionnames[a->passed->id]);
+      }
       
     } else if(dl->resource == RESOURCE_ID_SPACE) {
 	    
-      printf(" %-20s = if %s %ld %s then %s else if recovered then %s\n",
-        "Space usage limit",
-        operatornames[dl->operator],
-        (dl->limit_absolute > -1)?dl->limit_absolute:dl->limit_percent,
-        (dl->limit_absolute > -1)?"blocks":"%",
-        actionnames[a->failed->id], actionnames[a->passed->id]);
+      if(dl->limit_absolute > -1) {
+        printf(" %-20s = if %s %ld blocks then %s else if recovered then %s\n",
+          "Space usage limit",
+          operatornames[dl->operator],
+          dl->limit_absolute,
+          actionnames[a->failed->id], actionnames[a->passed->id]);
+      } else {
+        printf(" %-20s = if %s %.1f%% then %s else if recovered then %s\n",
+          "Space usage limit",
+          operatornames[dl->operator],
+          dl->limit_percent/10.,
+          actionnames[a->failed->id], actionnames[a->passed->id]);
+      }
 
     }
     
@@ -824,7 +858,7 @@ void printservice(Service_T s) {
     case RESOURCE_ID_CHILDREN:
 
       printf(" %-20s = If %s %ld for %d cycle(s) then %s "
-        "else if recovered then %s",
+        "else if recovered then %s\n",
         "Children", operatornames[q->operator], q->limit, q->max_cycle,
         actionnames[a->failed->id], actionnames[a->passed->id]);
       break;
@@ -832,7 +866,7 @@ void printservice(Service_T s) {
     case RESOURCE_ID_TOTAL_MEM_KBYTE:
 
       printf(" %-20s = If %s %ld for %d cycle(s) then %s "
-        "else if recovered then %s",
+        "else if recovered then %s\n",
         "Memory amount limit (incl. children)",
         operatornames[q->operator], q->limit, q->max_cycle,
         actionnames[a->failed->id], actionnames[a->passed->id]);
@@ -841,7 +875,7 @@ void printservice(Service_T s) {
     case RESOURCE_ID_TOTAL_MEM_PERCENT:
 
       printf(" %-20s = If %s %.1f%% for %d cycle(s) then %s "
-        "else if recovered then %s",
+        "else if recovered then %s\n",
         "Memory usage limit (incl. children)",
         operatornames[q->operator], q->limit/10.0, q->max_cycle,
         actionnames[a->failed->id], actionnames[a->passed->id]);
@@ -875,7 +909,7 @@ void printservice(Service_T s) {
 /**
  * Print all the services in the servicelist
  */
-void printservicelist() {
+void Util_printServiceList() {
 
   Service_T s;
   char ruler[STRLEN];
@@ -884,7 +918,7 @@ void printservicelist() {
   
   for(s= servicelist_conf; s; s= s->next_conf) {
     
-    printservice(s);
+    Util_printService(s);
     
   }
 
@@ -894,9 +928,9 @@ void printservicelist() {
 }
 
 /**
- * Print file hashes from stdin or file
+ * Print file hashes from stdin or from the given file
  */
-void printhash(char *filename) {
+void Util_printHash(char *filename) {
   
   unsigned char buf[STRLEN], buf2[STRLEN];
   FILE * fhandle;
@@ -904,71 +938,42 @@ void printhash(char *filename) {
   int i;
 
   if (filename == NULL) {
-    
     fhandle = stdin;
-    
   } else {
-    
     fhandle = fopen(filename, "r");
-
     if ( fhandle == NULL ) {
-
       goto fileerror;
-      
     }
   }
-  
-  fresult=sha_md5_stream(fhandle, buf, buf2);
-
+  fresult=Util_getStreamDigests(fhandle, buf, buf2);
   if(fresult) {
-
     goto fileerror;
-
   }
-
   if (filename==NULL) {
-    
-      printf("SHA1(stdin) = ");
-      
+    printf("SHA1(stdin) = ");
   } else {
-    
-      printf("SHA1(%s) = ", filename);
-      
-      fclose(fhandle);
+    printf("SHA1(%s) = ", filename);
+    fclose(fhandle);
   }
-      
   for(i= 0; i < 20; ++i) {
-    
-      printf("%02x", buf[i]);
-
+    printf("%02x", buf[i]);
   }
-  
   if (filename==NULL) {
-    
-      printf("\nMD5(stdin)  = ");
-      
+    printf("\nMD5(stdin)  = ");
   } else {
-    
-      printf("\nMD5(%s)  = ", filename);
-
+    printf("\nMD5(%s)  = ", filename);
   }
-  
   for(i= 0; i < 16; ++i) {
-    
-      printf("%02x", buf2[i]);
-      
+    printf("%02x", buf2[i]);
   }
-  
   printf("\n");
-  
+
   return;
 
 fileerror:
-  
-  printf("monit: %s: %s\n", filename, strerror(errno));
-  
-  exit(1);
 
+  printf("monit: %s: %s\n", filename, strerror(errno));
+  exit(1);
 }
 
 /**
@@ -977,46 +982,33 @@ fileerror:
  * @return the pid (TRUE) or FALSE if the pid could
  * not be read from the file
  */
-pid_t get_pid(char *pidfile) {
+pid_t Util_getPid(char *pidfile) {
   
   FILE *file= NULL;
   int pid= -1;
 
   ASSERT(pidfile);
 
-  if(! exist_file(pidfile)) {
-    
+  if(! File_exist(pidfile)) {
     return(FALSE);
-    
   }
-
-  if(! isreg_file(pidfile)) {
-    
+  if(! File_isFile(pidfile)) {
     log("%s: pidfile '%s' is not a regular file\n",prog, pidfile);
     return(FALSE);
-    
   }
-  
   if((file= fopen(pidfile,"r")) == (FILE *)NULL) {
-    
     log("%s: Error opening the pidfile '%s' -- %s\n",
 	prog, pidfile, STRERROR);
     return(FALSE);
-    
   }
-
   fscanf(file, "%d", &pid);
   fclose(file);
-
   if(pid == -1) {
-    
     log("%s: pidfile `%s' does not contain a valid pidnumber\n",
 	prog, pidfile);
-    
     return (FALSE);
-    
   }
-
+  
   return (pid_t)pid;
   
 }
@@ -1026,20 +1018,18 @@ pid_t get_pid(char *pidfile) {
  * @return TRUE (i.e. the running pid id)  if
  * the process is running, otherwise FALSE
  */
-int is_process_running(Service_T s) {
+int Util_isProcessRunning(Service_T s) {
   
   pid_t  pid;
 
   ASSERT(s);
   
   errno= 0;
-
-  if((pid= get_pid(s->path)))
+  if((pid= Util_getPid(s->path)))
     if( (getpgid(pid) > -1) || (errno == EPERM) )
       return pid;
-
-  reset_procinfo(s);
-
+  Util_resetInfo(s);
+  
   return FALSE;
   
 }
@@ -1047,25 +1037,25 @@ int is_process_running(Service_T s) {
 
 /**
  * Returns a RFC822 Date string. If the given date is NULL compute the
- * date now.
- * @param date
- * @return a date string or NULL if an error occured
+ * date now. If an error occured the result buffer is set to an empty
+ * string. The result buffer should be large enough to hold 33 bytes.
+ * @param date seconds since EPOCH
+ * @param result The buffer to write the date string to
+ * @param len the length of the result buffer
+ * @return a pointer to the result buffer
  */
-char *get_RFC822date(long *date) {
-
-  char D[STRLEN];
+char *Util_getRFC822Date(long *date, char *result, int len) {
+  
   struct tm *tm_now;
   time_t now= (date && *date>0)?*date:time(NULL);
-
+  
   tm_now= localtime(&now);
-
-  if(strftime(D, STRLEN, "%a, %d %b %Y %H:%M:%S %z", tm_now) <= 0) {
-
-    return NULL;
-
+  
+  if(strftime(result, len, "%a, %d %b %Y %H:%M:%S %z", tm_now) <= 0) {
+    *result= 0;
   }
-
-  return xstrdup(D);
+  
+  return result;
   
 }
 
@@ -1076,19 +1066,16 @@ char *get_RFC822date(long *date) {
  * @param pidfile A process pidfile
  * @return an uptime
  */
-time_t get_process_uptime(char *pidfile) {
+time_t Util_getProcessUptime(char *pidfile) {
 
   time_t ctime;
 
   ASSERT(pidfile);
 
-  if( (ctime= get_timestamp(pidfile, S_IFREG)) ) {
-
+  if((ctime= File_getTimestamp(pidfile, S_IFREG)) ) {
     time_t now= time(&now);
     time_t since= now-ctime;
-
     return since;
-
   }
 
   return (time_t)-1;
@@ -1103,7 +1090,7 @@ time_t get_process_uptime(char *pidfile) {
  * @param sep string separator
  * @return an uptime string
  */
-char *get_uptime(time_t delta, char *sep) {
+char *Util_getUptime(time_t delta, char *sep) {
 
   static int min= 60;
   static int hour= 3600;
@@ -1115,10 +1102,8 @@ char *get_uptime(time_t delta, char *sep) {
   char *p= buf;
 
   *buf= 0;
-
   if(delta < 0)
     return(xstrdup(""));
-
   if((rest_d= delta/day)>0) {
     p+= snprintf(p, STRLEN-(p-buf), "%ldd%s", rest_d,sep);
     delta-= rest_d*day;
@@ -1127,11 +1112,10 @@ char *get_uptime(time_t delta, char *sep) {
     p+= snprintf(p, STRLEN-(p-buf),"%ldh%s", rest_h,sep);
     delta-= rest_h*hour;
   }
-
   rest_m= delta/min;
   p+= snprintf(p, STRLEN-(p-buf),"%ldm%s", rest_m,sep);
   delta-= rest_m*min;
-
+  
   return xstrdup(buf);
 
 }
@@ -1140,70 +1124,55 @@ char *get_uptime(time_t delta, char *sep) {
 /**
  * @return a checksum for the given file, or NULL if error.
  */
-char *get_checksum(char *file, int hashtype) {
+char *Util_getChecksum(char *file, int hashtype) {
 
   int hashlength=16;
 
   ASSERT(file);
-
+  
   switch(hashtype) {
   case HASH_MD5:
-      hashlength=16;
-      break;
-
+    hashlength=16;
+    break;
   case HASH_SHA1:
-      hashlength=20;
-      break;
-      
+    hashlength=20;
+    break;
   default:
-      return NULL;
+    return NULL;
   }
-
-  if(isreg_file(file)) {
-    
+  
+  if(File_isFile(file)) {
     FILE *f= fopen(file, "r");
-    
     if(f) {
-      
       int i;
       unsigned char buf[hashlength];
       char result[STRLEN];
       char *r= result;
       int fresult=0;
-
+      
       *result=0;
-
+      
       switch(hashtype) {
       case HASH_MD5:
-          fresult=md5_stream(f, buf);
-          break;
-          
+	fresult=md5_stream(f, buf);
+	break;
       case HASH_SHA1:
-          fresult=sha_stream(f, buf);
-          break;
-      }
-      
-      if(fresult) {
-	
-	fclose(f);
-	
-	return NULL;
-	
+	fresult=sha_stream(f, buf);
+	break;
       }
       
       fclose(f);
-      
+      if(fresult) {
+	return NULL;
+      }
       for(i= 0; i < hashlength; ++i)
 	r+= snprintf(r, STRLEN-(r-result) ,"%02x", buf[i]);
-    
+      
       return (xstrdup(result));
       
     }
-    
   }
-  
   return NULL;
-
 }
 
 
@@ -1213,7 +1182,7 @@ char *get_checksum(char *file, int hashtype) {
  * @param uri an uri string
  * @return the escaped string
  */
-char *url_encode(char *uri) {
+char *Util_urlEncode(char *uri) {
 
   register int x, y;
   unsigned char *str;
@@ -1221,10 +1190,10 @@ char *url_encode(char *uri) {
 
   ASSERT(uri);
 
-  str= (unsigned char *)xmalloc(3 * strlen(uri) + 1);
+  str= (unsigned char *)xcalloc(sizeof(unsigned char), 3 * strlen(uri) + 1);
 
   for(x = 0, y = 0; uri[x]; x++, y++) {
-    if(is_unsafe((unsigned char*) &uri[x])) {
+    if(is_url_unsafe((unsigned char*) &uri[x])) {
       str[y++] = '%';
       str[y++] = hexchars[(unsigned char) uri[x] >> 4];
       str[y] = hexchars[(unsigned char) uri[x] & 0xf];
@@ -1244,12 +1213,12 @@ char *url_encode(char *uri) {
  * @param url an escaped url string
  * @return A pointer to the unescaped <code>url</code>string
  */
-char *url_decode(char *url) {
+char *Util_urlDecode(char *url) {
 
   register int x,y;
 
   if(!(url&&*url)) return url;
-  replace_char(url, '+', ' ');
+  Util_replace(url, '+', ' ');
   for(x=0,y=0;url[y];++x,++y) {
     if((url[x] = url[y]) == '%') {
       url[x]= x2c(&url[y+1]);
@@ -1263,53 +1232,38 @@ char *url_decode(char *url) {
 
 /**
  * @return a Basic Authentication Authorization string (RFC 2617),
- * with credentials from the Run object, The string "\r\n" if
- * credentials are not defined.
+ * with credentials from the Run object, NULL if credentials are not defined.
  */
-char *get_basic_authentication_header() {
+char *Util_getBasicAuthHeader() {
 
-  Auth_T c=Run.credentials;
+  Auth_T c= Run.credentials;
 
   if (c==NULL) {
-
-    return xstrdup("\r\n");
-
+    return NULL;
   }
   
   /* We find the first cleartext credential for authorization */
-  
   while (c!= NULL) {
-
     if (c->digesttype == DIGEST_CLEARTEXT) {
-
       break;
-      
     }
-    
     c=c->next;
-    
   }
-  
   if(c!=NULL) {
-
     char *auth, *b64;
     char  buf[STRLEN];
-
     snprintf(buf, STRLEN, "%s:%s",
              c->uname,
              c->passwd);
-
     if(! (b64= encode_base64(strlen(buf), (unsigned char *)buf)) ) {
       log("Failed to base64 encode authentication header\n");
+      FREE(b64);
       return NULL;
     }
-
     auth= xcalloc(sizeof(char), STRLEN+1);
     snprintf(auth, STRLEN, "Authorization: Basic %s\r\n", b64);
     FREE(b64);
-
     return auth;
-
   }
 
   log("Cleattext credentials needed for basic authorization!\n");
@@ -1318,6 +1272,31 @@ char *get_basic_authentication_header() {
 }
 
 
+/**
+ * Creates a new String by merging a formated string and a variable
+ * argument list. The caller must free the returned String.
+ * @param s A format string
+ * @return The new String or NULL if the string could not be created
+ */
+char *Util_getString(const char *s, ...) {
+
+  long l;
+  char *v;
+  va_list ap;
+  
+  ASSERT(s);
+  
+  if(s==NULL)
+    return NULL;
+  va_start(ap, s);
+  v= Util_formatString(s, ap, &l);
+  va_end(ap);
+
+  return v;
+
+}
+
+
 /**
  * Do printf style format line parsing
  * @param s format string
@@ -1326,47 +1305,36 @@ char *get_basic_authentication_header() {
  * may be different from the returned allocated buffer size
  * @return buffer with parsed string
  */
-char *format(const char *s, va_list ap, long *len) {
+char *Util_formatString(const char *s, va_list ap, long *len) {
 
   int n;
   int size= STRLEN;
-  char *buf= xmalloc(size);
-
+  char *buf= xcalloc(sizeof(char), size);
+  
 #ifdef HAVE_VA_COPY
   va_list ap_copy;
 #endif
-
+  
   ASSERT(s);
-   
+  
   while(TRUE) {
-
 #ifdef HAVE_VA_COPY
     va_copy(ap_copy, ap);
-      
     n= vsnprintf(buf, size, s, ap_copy);
-
     va_end(ap_copy);
-
 #else
-
     n= vsnprintf(buf, size, s, ap);
-
 #endif
-    
     if(n > -1 && n < size)
-        break;
-    
+      break;
     if(n > -1)
-        size= n+1;
+      size= n+1;
     else
-        size*= 2;
-    
+      size*= 2;
     buf= xresize(buf, size);
-    
   }
-
   *len= n;
-
+  
   return buf;
 
 }
@@ -1376,14 +1344,13 @@ char *format(const char *s, va_list ap, long *len) {
  * Redirect the standard file descriptors to /dev/null and route any
  * error messages to the log file.
  */
-void redirect_stdfd() {
-
+void Util_redirectStdFds() {
   int i;
-  
-  for(i= 0; i < 3; i++)
-    if(close(i) == -1 || open("/dev/null", O_RDWR) != i)
+  for(i= 0; i < 3; i++) {
+    if(close(i) == -1 || open("/dev/null", O_RDWR) != i) {
       log("Cannot reopen standard file descriptor (%d) -- %s\n", i, STRERROR);
-  
+    }
+  }
 }
 
 
@@ -1392,175 +1359,156 @@ void redirect_stdfd() {
  * seems to have getdtablesize, so we'll use it here, and back
  * out to use 1024 if getdtablesize not available.
  */
-void fd_close() {
-
+void Util_closeFds() {
   int i;
 #ifdef HAVE_UNISTD_H
   int max_descriptors = getdtablesize();
 #else
   int max_descriptors = 1024;
 #endif
-
   for(i = 3; i < max_descriptors; i++)
     (void) close(i);
-
   errno= 0;
-
 }
 
+
 /*
  * Check if monit does have credentials for this user.  If successful
  * a pointer to the password is returned.
  */
-Auth_T get_user_credentials(char *uname) {
-
+Auth_T Util_getUserCredentials(char *uname) {
   Auth_T c= Run.credentials;
-  
   while ( c != NULL ) {
-
     if ( strcmp(c->uname, uname) == 0 ) {
-
       return c;
-      
     }
-    
     c=c->next;
-    
   }
-
   return NULL;
 }
 
 
-int compare_user_credentials(char *uname, char *outside) {
-
-  Auth_T c= get_user_credentials(uname);
+/**
+ * Check if the given password match the registred password for the
+ * given username. 
+ * @param uname Username
+ * @param outside The password to test
+ * @return TRUE if the passwords match for the given uname otherwise
+ * FALSE
+ */
+int Util_checkCredentials(char *uname, char *outside) {
+  Auth_T c= Util_getUserCredentials(uname);
   char outside_crypt[STRLEN];
-  
-  if ( c==NULL ) {
-
+  if(c==NULL) {
     return FALSE;
-    
   }
   switch (c->digesttype) {
   case DIGEST_CLEARTEXT:
-  {
-    strncpy(outside_crypt, outside, STRLEN); 
-
-    break;
-  }   
+    {
+      strncpy(outside_crypt, outside, STRLEN); 
+      break;
+    }   
   case DIGEST_MD5:
-  {
-    char id[STRLEN];
-    char salt[STRLEN];
-    char * temp;
-
-    /* A password looks like this,
-     *   $id$salt$digest
-     * the '$' around the id are still part of the id. 
-     */
-
-    strncpy(id, c->passwd, STRLEN);
-    temp= strchr(id+1, '$')+1;
-    *temp= '\0';
-
-    strncpy(salt, c->passwd+strlen(id), STRLEN);
-    temp= strchr(salt, '$');
-    *temp= '\0';
-
-    if (md5_crypt(outside, id, salt, outside_crypt, STRLEN) == NULL) {
-
-      log("Cannot generate MD5 digest error.\n");
-      return FALSE;
-      
+    {
+      char id[STRLEN];
+      char salt[STRLEN];
+      char * temp;
+      /* A password looks like this,
+       *   $id$salt$digest
+       * the '$' around the id are still part of the id. 
+       */
+      strncpy(id, c->passwd, STRLEN);
+      temp= strchr(id+1, '$');
+      ASSERT(temp);
+      temp += 1;
+      *temp= '\0';
+      strncpy(salt, c->passwd+strlen(id), STRLEN);
+      temp= strchr(salt, '$');
+      ASSERT(temp);
+      *temp= '\0';
+      if (md5_crypt(outside, id, salt, outside_crypt, STRLEN) == NULL) {
+	log("Cannot generate MD5 digest error.\n");
+	return FALSE;
+      }
+      break;
     }
-    
-    break;
-  }
   case DIGEST_CRYPT:
-  {
-    char salt[3];
-    char * temp;
-    snprintf(salt, 3, "%c%c", c->passwd[0], c->passwd[1]);
-    temp= crypt(outside, salt);
-    strncpy(outside_crypt, temp, STRLEN); 
-    
-    break;
-  }
-  
+    {
+      char salt[3];
+      char * temp;
+      snprintf(salt, 3, "%c%c", c->passwd[0], c->passwd[1]);
+      temp= crypt(outside, salt);
+      strncpy(outside_crypt, temp, STRLEN); 
+      break;
+    }
   default:
-      log("Unknown password digestion method.\n");
-      return FALSE;
+    log("Unknown password digestion method.\n");
+    return FALSE;
   }
 
   if (strcmp(outside_crypt,c->passwd)==0) {
     return TRUE;
   }
-
   return FALSE;
 }
 
 
-/* Compute SHA1 and MD5 message digests simultaneously for bytes read
-   from STREAM (suitable for stdin, which is not always rewindable).
-   The resulting message digest numbers will be written into the first bytes
-   of resblock buffers.  */
-int sha_md5_stream (FILE *stream, void *sha_resblock, void *md5_resblock)
-{
-/* Important: HASHBLOCKSIZE must be a multiple of 64.  */
-#define HASHBLOCKSIZE 4096
+/**
+ * Compute SHA1 and MD5 message digests simultaneously for bytes read
+ * from STREAM (suitable for stdin, which is not always rewindable).
+ * The resulting message digest numbers will be written into the first
+ * bytes of resblock buffers.
+ * @param stream The stream from where the digests are computed
+ * @param sha_resblock The buffer to write the SHA1 result to
+ * @param md5_resblock The buffer to write the MD5 result to
+ */
+int Util_getStreamDigests (FILE *stream, void *sha_resblock, void *md5_resblock) {
+#define HASHBLOCKSIZE 4096 /* Important: must be a multiple of 64.  */
   struct sha_ctx ctx_sha;
   struct md5_ctx ctx_md5;
   char buffer[HASHBLOCKSIZE + 72];
   size_t sum;
-
+  
   /* Initialize the computation contexts.  */
   sha_init_ctx (&ctx_sha);
   md5_init_ctx (&ctx_md5);
-
+  
   /* Iterate over full file contents.  */
-  while (1)
-    {
-      /* We read the file in blocks of HASHBLOCKSIZE bytes.  One call of the
-	 computation function processes the whole buffer so that with the
-	 next round of the loop another block can be read.  */
-      size_t n;
-      sum = 0;
-
-      /* Read block.  Take care for partial reads.  */
-      while (1)
-	{
-	  n = fread (buffer + sum, 1, HASHBLOCKSIZE - sum, stream);
-
-	  sum += n;
-
-	  if (sum == HASHBLOCKSIZE)
-	    break;
-
-	  if (n == 0)
-	    {
-	      /* Check for the error flag IFF N == 0, so that we don't
-		 exit the loop after a partial read due to e.g., EAGAIN
-		 or EWOULDBLOCK.  */
-	      if (ferror (stream))
-		return 1;
-	      goto process_partial_block;
-	    }
-
-	  /* We've read at least one byte, so ignore errors.  But always
-	     check for EOF, since feof may be true even though N > 0.
-	     Otherwise, we could end up calling fread after EOF.  */
-	  if (feof (stream))
-	    goto process_partial_block;
-	}
-
-      /* Process buffer with HASHBLOCKSIZE bytes.  Note that
-			HASHBLOCKSIZE % 64 == 0
-       */
-      sha_process_block (buffer, HASHBLOCKSIZE, &ctx_sha);
-      md5_process_block (buffer, HASHBLOCKSIZE, &ctx_md5);
+  while (1)  {
+    /* We read the file in blocks of HASHBLOCKSIZE bytes.  One call of the
+       computation function processes the whole buffer so that with the
+       next round of the loop another block can be read.  */
+    size_t n;
+    sum = 0;
+    
+    /* Read block.  Take care for partial reads.  */
+    while (1) {
+      n = fread (buffer + sum, 1, HASHBLOCKSIZE - sum, stream);
+      sum += n;
+      if (sum == HASHBLOCKSIZE)
+	break;
+      if (n == 0) {
+	/* Check for the error flag IFF N == 0, so that we don't
+	   exit the loop after a partial read due to e.g., EAGAIN
+	   or EWOULDBLOCK.  */
+	if (ferror (stream))
+	  return 1;
+	goto process_partial_block;
+      }
+      
+      /* We've read at least one byte, so ignore errors.  But always
+	 check for EOF, since feof may be true even though N > 0.
+	 Otherwise, we could end up calling fread after EOF.  */
+      if (feof (stream))
+	goto process_partial_block;
     }
 
+    /* Process buffer with HASHBLOCKSIZE bytes.  Note that
+       HASHBLOCKSIZE % 64 == 0 */
+    sha_process_block (buffer, HASHBLOCKSIZE, &ctx_sha);
+    md5_process_block (buffer, HASHBLOCKSIZE, &ctx_md5);
+  }
+
 process_partial_block:
 
   /* Process any remaining bytes.  */
@@ -1568,7 +1516,6 @@ process_partial_block:
     sha_process_bytes (buffer, sum, &ctx_sha);
     md5_process_bytes (buffer, sum, &ctx_md5);
   }
-
   /* Construct result in desired memory.  */
   sha_finish_ctx (&ctx_sha, sha_resblock);
   md5_finish_ctx (&ctx_md5, md5_resblock);
@@ -1577,11 +1524,100 @@ process_partial_block:
 
 
 /**
-  * Reset process information structure
-  */
-void reset_procinfo(Service_T s) {
-
+ * Reset the service information structure
+ */
+void Util_resetInfo(Service_T s) {
   memset(s->inf, 0, sizeof *(s->inf));
+  s->inf->_pid=  -1;
+  s->inf->_ppid= -1;
+  s->inf->pid=   -1;
+  s->inf->ppid=  -1;
+}
+
+
+/**
+ * Are service status data available?
+ * @param s The service to test
+ * @return TRUE if available otherwise FALSE
+ */
+int Util_hasServiceStatus(Service_T s) {
+  return(!((s->monitor!=MONITOR_YES)||
+	   (s->error&EVENT_NONEXIST)||
+	   (s->error&EVENT_DATA) ));
+}
+
+
+/**
+ * Construct a HTTP/1.1 Host header utilizing information from the
+ * socket. The returned hostBuf is set to "hostname:port" or to the
+ * empty string if information is not available or not applicable.
+ * @param s A connected socket 
+ * @param hostBuf the buffer to write the host-header to
+ * @param len Length of the hostBuf
+ * @return the hostBuffer
+ */
+char *Util_getHTTPHostHeader(Socket_T s, char *hostBuf, int len) {
+  if(! strcmp(LOCALHOST, socket_get_remote_host(s)) ||
+     inet_aton(socket_get_remote_host(s), NULL)) {
+    *hostBuf= 0;
+  } else {
+    snprintf(hostBuf, len, "%s:%d", 
+	     socket_get_remote_host(s),
+	     socket_get_remote_port(s));
+  }
+  return hostBuf;
+}
+
+
+/**
+ * Evaluate a qualification expression. 
+ * @param operator The qualification operator
+ * @param left Expression lval
+ * @param rightExpression rval
+ * Returns the boolean value of the expression
+ */
+int Util_evalQExpression(int operator, int left, int right) {
+
+  switch(operator) {
+  case OPERATOR_GREATER:
+      if(left > right)
+	  return TRUE;
+      break;
+  case OPERATOR_LESS:
+      if(left < right)
+	  return TRUE;
+      break;
+  case OPERATOR_EQUAL:
+      if(left == right)
+	  return TRUE;
+      break;
+  case OPERATOR_NOTEQUAL:
+      if(left != right)
+	  return TRUE;
+      break;
+  default:
+      log("Unknown comparison operator\n");
+      return FALSE;
+  }
+
+  return FALSE;
+    
+}
+
+
+/*
+ * This will disable service monitoring in the case that it is enabled
+ * @param s A Service_T object
+ */
+void Util_monitorUnset(Service_T s) {
+
+  ASSERT(s);
+
+  s->monitor= MONITOR_NOT;
+  s->nstart= 0;
+  s->ncycle= 0;
+  Util_resetInfo(s);
+  DEBUG("Monitoring disabled -- service %s\n", s->name);
 
 }
 
@@ -1590,13 +1626,11 @@ void reset_procinfo(Service_T s) {
 
 
 /**
- * Returns the value of the variable if defined or the String
- * "(not defined)"
+ * Returns the value of the parameter if defined or the String "(not
+ * defined)"
  */
-static char *is_str_defined(char *var) {
-  
-  return (is_strdefined(var)?var:"(not defined)");
-  
+static char *is_str_defined(char *s) {
+  return ((s&&*s)?s:"(not defined)");
 }
 
 
@@ -1605,26 +1639,21 @@ static char *is_str_defined(char *var) {
  * @param c A unsigned char
  * @return TRUE if the char is in the set of unsafe URL Characters
  */
-static int is_unsafe(unsigned char *c) {
-
+static int is_url_unsafe(unsigned char *c) {
   int i;
   static unsigned char unsafe[]= "<>\"#{}|\\^~[]`";
-
+  
   ASSERT(c);
   
   if(33>*c || *c>176)
-      return TRUE;
-  
+    return TRUE;
   if(*c=='%') {
     if( isxdigit(*(c + 1)) && isxdigit(*(c + 2)) ) return FALSE;
     return TRUE;
   }
-
   for(i=0; unsafe[i]; i++)
     if(*c==unsafe[i]) return TRUE;
-
   return FALSE;
-
 }
 
 
@@ -1632,15 +1661,11 @@ static int is_unsafe(unsigned char *c) {
  * Convert a hex char to a char
  */
 static char x2c(char *hex) {
-  
   register char digit;
-  
   digit = ((hex[0] >= 'A') ? ((hex[0] & 0xdf) - 'A')+10 : (hex[0] - '0'));
   digit *= 16;
   digit += (hex[1] >= 'A' ? ((hex[1] & 0xdf) - 'A')+10 : (hex[1] - '0'));
-  
   return(digit);
-  
 }
 
 
@@ -1648,7 +1673,6 @@ static char x2c(char *hex) {
  * Print registered events list
  */
 static void printevents(unsigned int events) {
-
   if(events == (~((unsigned int)0))) {
     printf("All events");
   } else {
