@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2004 by the monit project group.
+ * Copyright (C), 2000-2005 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -90,7 +90,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: validate.c,v 1.123 2004/08/16 22:38:33 martinp Exp $
+ *  @version \$Id: validate.c,v 1.135 2005/03/14 22:30:14 martinp Exp $
  *  @file
  */
 
@@ -98,19 +98,20 @@
 /* -------------------------------------------------------------- Prototypes */
 
 
-static void check_process_state(Service_T);
-static void check_process_resources(Service_T, Resource_T);
-static void check_process_connection(Service_T, Port_T);
-static void check_device_resources(Service_T, Device_T);
-static void check_timestamp(Service_T);
-static void check_checksum(Service_T);
-static void check_perm(Service_T);
 static void check_uid(Service_T);
 static void check_gid(Service_T);
 static void check_size(Service_T);
-static int  compare_value(int, int, int);
-static int  check_timeout(Service_T);
+static void check_perm(Service_T);
 static int  check_skip(Service_T);
+static int  check_timeout(Service_T);
+static void check_checksum(Service_T);
+static void check_timestamp(Service_T);
+static void check_process_state(Service_T);
+static void check_process_pid(Service_T);
+static void check_process_ppid(Service_T);
+static void check_connection(Service_T, Port_T);
+static void check_device_resources(Service_T, Device_T);
+static void check_process_resources(Service_T, Resource_T);
 
 ProcessTree_T *ptree=NULL;     
 int            ptreesize=0;    
@@ -131,11 +132,11 @@ void validate() {
   Service_T s;
   sigset_t ns, os;
 
-  if(Run.doprocess)
+  if(Run.doprocess) {
     initprocesstree(&ptree, &ptreesize, &oldptree, &oldptreesize);
-
-  if(! update_system_load(ptree, ptreesize))
-    log("Update of loadavg has failed!\n");
+    if(! update_system_load(ptree, ptreesize))
+      log("Update of system load has failed!\n");
+  }
   time(&systeminfo.collected);
 
   for(s= servicelist; s; s= s->next) {
@@ -157,6 +158,9 @@ void validate() {
 
   reset_depend();
 
+  /* Post current status to the collector */
+  handle_collector(NULL);
+
 }
 
 
@@ -173,9 +177,9 @@ int check_process(Service_T s) {
   ASSERT(s);
 
   /* Test for running process */
-  if(!(pid= is_process_running(s))) {
-    /* Reset the proc info object to prevent false data in the first run */
-    reset_procinfo(s);
+  if(!(pid= Util_isProcessRunning(s))) {
+    /* Reset the service info object to prevent false data in the first run */
+    Util_resetInfo(s);
     Event_post(s, EVENT_NONEXIST, TRUE, s->action_NONEXIST,
       "'%s' process is not running", s->name);
     return FALSE;
@@ -184,11 +188,13 @@ int check_process(Service_T s) {
       "'%s' process is running with pid %d", s->name, (int)pid);
   }
 
-  s->inf->uptime= get_process_uptime(s->path);
+  s->inf->uptime= Util_getProcessUptime(s->path);
 
   if(Run.doprocess) {
     if(update_process_data(s, ptree, ptreesize, pid)) {
       check_process_state(s);
+      check_process_pid(s);
+      check_process_ppid(s);
       for(pr= s->resourcelist; pr; pr= pr->next) {
         check_process_resources(s, pr);
       }
@@ -201,7 +207,7 @@ int check_process(Service_T s) {
   /* Test each host:port and protocol in the service's portlist */
   if(s->portlist)
     for(pp= s->portlist; pp; pp= pp->next)
-      check_process_connection(s, pp);
+      check_connection(s, pp);
 
   return TRUE;
   
@@ -233,9 +239,17 @@ int check_device(Service_T s) {
 
   if(!device_usage(s->inf, s->path)) {
     Event_post(s, EVENT_DATA, TRUE, s->action_DATA,
-      "'%s' unable to read device %s state\n", s->name, s->path);
+      "'%s' unable to read device %s state", s->name, s->path);
     return FALSE;
   } else {
+    s->inf->inode_percent=
+      (int)((1000.0 * (s->inf->f_files - s->inf->f_filesfree)) /
+            (float)s->inf->f_files);
+    s->inf->space_percent=
+      (int)((1000.0 * (s->inf->f_blocks - s->inf->f_blocksfree)) /
+            (float)s->inf->f_blocks);
+    s->inf->inode_total= s->inf->f_files - s->inf->f_filesfree;
+    s->inf->space_total= s->inf->f_blocks - s->inf->f_blocksfreetotal;
     Event_post(s, EVENT_DATA, FALSE, s->action_DATA,
       "'%s' succeeded getting device statistic for %s", s->name, s->path);
   }
@@ -409,7 +423,7 @@ int check_remote_host(Service_T s) {
   /* Test each host:port and protocol in the service's portlist */
   if(s->portlist)
     for(p= s->portlist; p; p= p->next)
-      check_process_connection(s, p);
+      check_connection(s, p);
 
   return TRUE;
   
@@ -422,7 +436,7 @@ int check_remote_host(Service_T s) {
 /**
  * Test the connection and protocol
  */
-static void check_process_connection(Service_T s, Port_T p) {
+static void check_connection(Service_T s, Port_T p) {
 
   Socket_T socket;
   volatile int rv= TRUE;
@@ -503,9 +517,7 @@ static void check_process_state(Service_T s) {
   if(s->inf->status_flag & PROCESS_ZOMBIE) {
     /* We do not check the process anymore if it's a zombie
        since such a process is (usually) unmanageable */
-    LOCK(s->mutex)
-      s->monitor= MONITOR_NOT;
-    END_LOCK;
+    Util_monitorUnset(s);
     Event_post(s, EVENT_DATA, TRUE, s->action_DATA,
       "'%s' process with pid %d is a zombie", s->name, s->inf->pid);
   } else {
@@ -518,6 +530,48 @@ static void check_process_state(Service_T s) {
 }
 
 
+/**
+ * Test process pid for possible change since last cycle
+ */
+static void check_process_pid(Service_T s) {
+
+  ASSERT(s && s->inf);
+
+  /* process pid was not initialized yet */
+  if(s->inf->_pid == -1)
+    return;
+
+  if(s->inf->_pid != s->inf->pid) {
+    Event_post(s, EVENT_CHANGED, TRUE, s->action_PID,
+      "'%s' process PID changed to %d", s->name, s->inf->pid);
+  } else {
+    Event_post(s, EVENT_CHANGED, FALSE, s->action_PID,
+      "'%s' PID has not changed", s->name);
+  }
+}
+
+
+/**
+ * Test process ppid for possible change since last cycle
+ */
+static void check_process_ppid(Service_T s) {
+
+  ASSERT(s && s->inf);
+
+  /* process ppid was not initialized yet */
+  if(s->inf->_ppid == -1)
+    return;
+
+  if(s->inf->_ppid != s->inf->ppid) {
+    Event_post(s, EVENT_CHANGED, TRUE, s->action_PPID,
+      "'%s' process PPID changed to %d", s->name, s->inf->ppid);
+  } else {
+    Event_post(s, EVENT_CHANGED, FALSE, s->action_PPID,
+      "'%s' PPID has not changed", s->name);
+  }
+}
+
+
 /**
  * Check process resources
  */
@@ -530,7 +584,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
 
   switch(pr->resource_id) {
   case RESOURCE_ID_CPU_PERCENT:
-    if(compare_value(pr->operator, s->inf->cpu_percent, pr->limit)) {
+    if(Util_evalQExpression(pr->operator, s->inf->cpu_percent, pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' cpu usage of %.1f%% matches resource limit [cpu usage%s%.1f%%]",
         s->name, s->inf->cpu_percent/10.0, operatorshortnames[pr->operator],
@@ -543,7 +597,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_MEM_PERCENT:
-    if(compare_value(pr->operator, s->inf->mem_percent, pr->limit)) {
+    if(Util_evalQExpression(pr->operator, s->inf->mem_percent, pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' mem usage of %.1f%% matches resource limit [mem usage%s%.1f%%]",
         s->name, s->inf->mem_percent/10.0, operatorshortnames[pr->operator],
@@ -556,7 +610,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_MEM_KBYTE:
-    if(compare_value(pr->operator, s->inf->mem_kbyte, pr->limit)) {
+    if(Util_evalQExpression(pr->operator, s->inf->mem_kbyte, pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' mem amount of %ldkB matches resource limit [mem amount%s%ldkB]",
         s->name, s->inf->mem_kbyte, operatorshortnames[pr->operator], pr->limit);
@@ -568,7 +622,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_LOAD1:
-    if(compare_value(pr->operator,
+    if(Util_evalQExpression(pr->operator,
                      (int)(systeminfo.loadavg[0]*10.0), pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' loadavg(1min) of %.1f matches resource limit "
@@ -583,7 +637,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_LOAD5:
-    if(compare_value(pr->operator,
+    if(Util_evalQExpression(pr->operator,
                      (int)(systeminfo.loadavg[1]*10.0), pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' loadavg(5min) of %.1f matches resource limit "
@@ -598,7 +652,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_LOAD15:
-    if(compare_value(pr->operator,
+    if(Util_evalQExpression(pr->operator,
                      (int)(systeminfo.loadavg[2]*10.0), pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' loadavg(15min) of %.1f matches resource limit "
@@ -613,7 +667,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_CHILDREN:
-    if(compare_value(pr->operator, s->inf->children, pr->limit)) {
+    if(Util_evalQExpression(pr->operator, s->inf->children, pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' children of %i matches resource limit [children%s%ld]",
         s->name, s->inf->children, operatorshortnames[pr->operator], pr->limit);
@@ -625,7 +679,7 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     break;
 
   case RESOURCE_ID_TOTAL_MEM_KBYTE:
-    if(compare_value(pr->operator, s->inf->total_mem_kbyte, pr->limit)) {
+    if(Util_evalQExpression(pr->operator, s->inf->total_mem_kbyte, pr->limit)) {
       snprintf(report, STRLEN,
         "'%s' total mem amount of %ldkB matches resource limit"
         " [total mem amount%s%ldkB]",
@@ -638,6 +692,21 @@ static void check_process_resources(Service_T s, Resource_T pr) {
     }
     break;
 
+  case RESOURCE_ID_TOTAL_MEM_PERCENT:
+    if(Util_evalQExpression(pr->operator, s->inf->total_mem_percent, pr->limit)) {
+      snprintf(report, STRLEN,
+        "'%s' total mem amount of %.1f%% matches resource limit"
+        " [total mem amount%s%.1f%%]",
+        s->name, (float)s->inf->total_mem_percent/10.0,
+        operatorshortnames[pr->operator], (float)pr->limit/10.0);
+      okay= FALSE;
+    } else {
+      DEBUG("'%s' total mem amount check passed "
+        "[current total mem amount=%.1f%%]\n", s->name,
+         s->inf->total_mem_percent/10.0);
+    }
+    break;
+
   default:
     log("'%s' error -- unknown resource ID: [%d]\n", s->name, pr->resource_id);
     return;
@@ -673,7 +742,7 @@ static void check_checksum(Service_T s) {
   cs= s->checksum;
 
   FREE(s->inf->cs_sum);
-  s->inf->cs_sum= get_checksum(s->path, cs->type);
+  s->inf->cs_sum= Util_getChecksum(s->path, cs->type);
 
   if(s->inf->cs_sum) {
 
@@ -828,7 +897,7 @@ static void check_timestamp(Service_T s) {
       break;
     } else {
     /* we are testing constant value for failed or passed state */
-      if(compare_value(t->operator, (int)(now - s->inf->timestamp), t->time)) {
+      if(Util_evalQExpression(t->operator, (int)(now - s->inf->timestamp), t->time)) {
         Event_post(s, EVENT_TIMESTAMP, TRUE, t->action,
           "'%s' timestamp test failed for %s", s->name, s->path);
       } else {
@@ -869,7 +938,7 @@ static void check_size(Service_T s) {
     }
 
     /* we are testing constant value for failed or passed state */
-    if(compare_value(sl->operator, s->inf->st_size, sl->size)) {
+    if(Util_evalQExpression(sl->operator, s->inf->st_size, sl->size)) {
       Event_post(s, EVENT_SIZE, TRUE, sl->action,
         "'%s' size test failed for %s -- current size is %lu B",
         s->name, s->path, s->inf->st_size);
@@ -903,67 +972,57 @@ static void check_device_resources(Service_T s, Device_T td) {
       }
 
       if(td->limit_percent >= 0) {
-	if(compare_value(
-	       td->operator,
-	       100 * (s->inf->f_files - s->inf->f_filesfree) /
-	       s->inf->f_files, td->limit_percent)) {
+	if(Util_evalQExpression( td->operator, s->inf->inode_percent, td->limit_percent)) {
           Event_post(s, EVENT_RESOURCE, TRUE, td->action,
-            "'%s' inode usage %ld%% matches resource limit [inode usage%s%d%%]",
+            "'%s' inode usage %.1f%% matches resource limit [inode usage%s%.1f%%]",
             s->name,
-	    100 * (s->inf->f_files - s->inf->f_filesfree) /
-	    s->inf->f_files, operatorshortnames[td->operator],
-	    td->limit_percent);
+	    s->inf->inode_percent/10.,
+            operatorshortnames[td->operator],
+	    td->limit_percent/10.);
 	  return;
 	}
       } else {
-	if(compare_value(td->operator, s->inf->f_files -
-			 s->inf->f_filesfree, td->limit_absolute)) {
+	if(Util_evalQExpression(td->operator, s->inf->inode_total, td->limit_absolute)) {
           Event_post(s, EVENT_RESOURCE, TRUE, td->action,
             "'%s' inode usage %ld matches resource limit [inode usage%s%ld]",
             s->name,
-            s->inf->f_files - s->inf->f_filesfree,
-            operatorshortnames[td->operator], td->limit_absolute);
+            s->inf->inode_total,
+            operatorshortnames[td->operator],
+            td->limit_absolute);
 	  return;
 	}
       }
       DEBUG("'%s' inode usage check passed [current inode usage=%.1f%%]\n",
-	    s->name,
-	    (float) 100 * (s->inf->f_files - s->inf->f_filesfree) /
-	    s->inf->f_files);
+	    s->name, s->inf->inode_percent/10.);
       Event_post(s, EVENT_RESOURCE, FALSE, td->action,
         "'%s' device resources passed", s->name);
       return;
 
   case RESOURCE_ID_SPACE:
       if(td->limit_percent >= 0) {
-        if(compare_value(
-	       td->operator,
-	       100 * (s->inf->f_blocks - s->inf->f_blocksfreetotal) /
-	       s->inf->f_blocks, td->limit_percent)) {
+        if(Util_evalQExpression( td->operator, s->inf->space_percent, td->limit_percent)) {
           Event_post(s, EVENT_RESOURCE, TRUE, td->action,
-	    "'%s' space usage %ld%% matches resource limit [space usage%s%d%%]",
+	    "'%s' space usage %.1f%% matches resource limit [space usage%s%.1f%%]",
             s->name,
-            100*(s->inf->f_blocks - s->inf->f_blocksfreetotal) /
-            s->inf->f_blocks, operatorshortnames[td->operator],
-            td->limit_percent);
+            s->inf->space_percent/10.,
+            operatorshortnames[td->operator],
+            td->limit_percent/10.);
           return;
         }
       } else {
-        if(compare_value(td->operator, s->inf->f_blocks -
-			 s->inf->f_blocksfreetotal, td->limit_absolute)) {
+        if(Util_evalQExpression(td->operator, s->inf->space_total, td->limit_absolute)) {
           Event_post(s, EVENT_RESOURCE, TRUE, td->action,
             "'%s' space usage %ld blocks matches resource limit "
             "[space usage%s%ld blocks]",
             s->name,
-            s->inf->f_blocks - s->inf->f_blocksfreetotal,
-            operatorshortnames[td->operator], td->limit_absolute);
+            s->inf->space_total,
+            operatorshortnames[td->operator],
+            td->limit_absolute);
 	  return;
         }
       }
       DEBUG("'%s' space usage check passed [current space usage=%.1f%%]\n",
-	    s->name,
-	    (float) 100*(s->inf->f_blocks - s->inf->f_blocksfreetotal) /
-	    s->inf->f_blocks);
+	    s->name, s->inf->space_percent/10.);
       Event_post(s, EVENT_RESOURCE, FALSE, td->action,
         "'%s' device resources passed", s->name);
       return;
@@ -976,39 +1035,6 @@ static void check_device_resources(Service_T s, Device_T td) {
 }
 
 
-/**
- * Comparison of values. Returns TRUE if comparison matches, otherwise
- * FALSE.
- */
-static int compare_value(int operator, int left, int right) {
-
-  switch(operator) {
-  case OPERATOR_GREATER:
-      if(left > right)
-	  return TRUE;
-      break;
-  case OPERATOR_LESS:
-      if(left < right)
-	  return TRUE;
-      break;
-  case OPERATOR_EQUAL:
-      if(left == right)
-	  return TRUE;
-      break;
-  case OPERATOR_NOTEQUAL:
-      if(left != right)
-	  return TRUE;
-      break;
-  default:
-      log("Unknown comparison operator\n");
-      return FALSE;
-  }
-
-  return FALSE;
-    
-}
-
-
 /**
  * Returns TRUE if the service timed out, otherwise FALSE.
  */
